
package Google::Ads::AdWords::v201402::TypeMaps::TrafficEstimatorService;
use strict;
use warnings;

our $typemap_1 = {
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201402::EntityNotFound::Reason',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/totalCost' => 'Google::Ads::AdWords::v201402::Money',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201402::NotEmptyError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201402::RateExceededError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201402::RegionCodeError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201402::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/reason' => 'Google::Ads::AdWords::v201402::CurrencyCodeError::Reason',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests' => 'Google::Ads::AdWords::v201402::CampaignEstimateRequest',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]' => 'Google::Ads::AdWords::v201402::TargetError',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201402::OperationAccessDenied',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates' => 'Google::Ads::AdWords::v201402::AdGroupEstimate',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201402::RegionCodeError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201402::DateError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201402::RateExceededError',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/totalCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/networkSetting' => 'Google::Ads::AdWords::v201402::NetworkSetting',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Language]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/totalCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201402::QuotaCheckError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201402::DatabaseError::Reason',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201402::DateError',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201402::ClientTermsError::Reason',
               'get/selector/campaignEstimateRequests/criteria[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201402::InternalApiError',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria' => 'Google::Ads::AdWords::v201402::Criterion',
               'get/selector/campaignEstimateRequests/criteria[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/selector/campaignEstimateRequests/criteria[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/Estimate.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse' => 'Google::Ads::AdWords::v201402::TrafficEstimatorService::getResponse',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'getResponse/rval/campaignEstimates/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval' => 'Google::Ads::AdWords::v201402::TrafficEstimatorResult',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/Estimate.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201402::ClientTermsError',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/Estimate.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201402::InternalApiError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201402::RejectedError::Reason',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/reason' => 'Google::Ads::AdWords::v201402::TrafficEstimatorError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/keyword/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/keyword/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/totalCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201402::DatabaseError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201402::AuthorizationError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/totalCost' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201402::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/impressionsPerDay' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'get/selector/campaignEstimateRequests/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]' => 'Google::Ads::AdWords::v201402::CollectionSizeError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/maxCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201402::RangeError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201402::ReadOnlyError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201402::RequestError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201402::RequiredError',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests' => 'Google::Ads::AdWords::v201402::AdGroupEstimateRequest',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201402::NotEmptyError',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201402::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max' => 'Google::Ads::AdWords::v201402::StatsEstimate',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201402::EntityAccessDenied',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]' => 'Google::Ads::AdWords::v201402::CurrencyCodeError',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/maxCpc' => 'Google::Ads::AdWords::v201402::Money',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'get/selector' => 'Google::Ads::AdWords::v201402::TrafficEstimatorSelector',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/keyword/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/clickThroughRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201402::AuthenticationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/maxCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201402::StringLengthError::Reason',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[AdxError]' => 'Google::Ads::AdWords::v201402::AdxError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/clicksPerDay' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]' => 'Google::Ads::AdWords::v201402::TrafficEstimatorError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201402::OperatorError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/EstimateRequest.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/keyword/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/EstimateRequest.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Language]' => 'Google::Ads::AdWords::v201402::Language',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/keyword/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get' => 'Google::Ads::AdWords::v201402::TrafficEstimatorService::get',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/selector/campaignEstimateRequests/criteria[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/maxCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201402::QuotaCheckError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'get/selector/campaignEstimateRequests/criteria[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201402::StringLengthError',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201402::EntityNotFound',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates' => 'Google::Ads::AdWords::v201402::CampaignEstimate',
               'get/selector/campaignEstimateRequests/criteria[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/reason' => 'Google::Ads::AdWords::v201402::MatchesRegexError::Reason',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/totalCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201402::DistinctError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests' => 'Google::Ads::AdWords::v201402::KeywordEstimateRequest',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201402::NullError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/dailyBudget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/impressionsPerDay' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201402::TargetError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Location]/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min' => 'Google::Ads::AdWords::v201402::StatsEstimate',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/dailyBudget' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201402::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/criterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates' => 'Google::Ads::AdWords::v201402::KeywordEstimate',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/averageCpc' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/clicksPerDay' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201402::RequiredError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201402::AdxError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/dailyBudget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201402::ReadOnlyError::Reason',
               'get/selector/campaignEstimateRequests/criteria[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201402::NullError::Reason',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201402::IdError::Reason',
               'get/selector/campaignEstimateRequests/criteria/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'get/selector/campaignEstimateRequests/criteria[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/keywordEstimateRequests/keyword' => 'Google::Ads::AdWords::v201402::Keyword',
               'get/selector/campaignEstimateRequests/criteria[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201402::SizeLimitError::Reason',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/min/clickThroughRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201402::DistinctError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201402::RequestError::Reason',
               'get/selector/campaignEstimateRequests/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201402::EntityAccessDenied::Reason',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201402::IdError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201402::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201402::OperationAccessDenied::Reason',
               'get/selector/campaignEstimateRequests/criteria[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/maxCpc' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/campaignEstimates/adGroupEstimates/keywordEstimates/max/averageCpc' => 'Google::Ads::AdWords::v201402::Money',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201402::RejectedError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/adGroupEstimateRequests/maxCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]' => 'Google::Ads::AdWords::v201402::OperatorError',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/EstimateRequest.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201402::Location',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]' => 'Google::Ads::AdWords::v201402::MatchesRegexError',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignEstimateRequests/criteria[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201402::TypeMaps::TrafficEstimatorService - typemap for TrafficEstimatorService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

