
package Google::Ads::AdWords::v201402::TypeMaps::ConversionTrackerService;
use strict;
use warnings;

our $typemap_1 = {
               'mutateResponse/rval/value[UploadConversion]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdWordsConversionTracker]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdWordsConversionTracker]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdCallMetricsConversion]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AppConversion]' => 'Google::Ads::AdWords::v201402::AppConversion',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ConversionTrackingError]' => 'Google::Ads::AdWords::v201402::ConversionTrackingError',
               'getResponse/rval/entries[AdCallMetricsConversion]' => 'Google::Ads::AdWords::v201402::AdCallMetricsConversion',
               'getResponse/rval/entries[AdWordsConversionTracker]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201402::Predicate',
               'mutateResponse/rval/value[AppConversion]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'getResponse/rval/entries[AppConversion]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AppConversion]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201402::NotEmptyError::Reason',
               'getResponse/rval/entries[AppConversion]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdCallMetricsConversion]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'mutateResponse/rval/value[AdWordsConversionTracker]/markupLanguage' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker::MarkupLanguage',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201402::RateExceededError::Reason',
               'mutate/operations/operand[AppConversion]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdWordsConversionTracker]/markupLanguage' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker::MarkupLanguage',
               'getResponse/rval/entries[UploadConversion]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[UploadConversion]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201402::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201402::Paging',
               'getResponse/rval/entries[AppConversion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[UploadConversion]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdWordsConversionTracker]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[UploadConversion]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201402::ConversionTracker',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'mutate/operations/operand[AdWordsConversionTracker]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'mutateResponse/rval/value[AppConversion]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[UploadConversion]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[AdWordsConversionTracker]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[AdWordsConversionTracker]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ConversionTrackingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdWordsConversionTracker]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'getResponse/rval/entries[AppConversion]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[UploadConversion]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AppConversion]/appPlatform' => 'Google::Ads::AdWords::v201402::AppConversion::AppPlatform',
               'mutate/operations/operand[AdCallMetricsConversion]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AppConversion]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201402::Predicate::Operator',
               'mutateResponse/rval/value[AdWordsConversionTracker]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdWordsConversionTracker]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[UploadConversion]' => 'Google::Ads::AdWords::v201402::UploadConversion',
               'mutate/operations/operand[AdCallMetricsConversion]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[AdCallMetricsConversion]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[AdCallMetricsConversion]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201402::OperationAccessDenied',
               'mutate/operations/operand[UploadConversion]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[UploadConversion]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdCallMetricsConversion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdCallMetricsConversion]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AppConversion]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'mutate/operations/operand[AdCallMetricsConversion]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[UploadConversion]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201402::DateError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201402::RateExceededError',
               'mutate/operations/operand[UploadConversion]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[UploadConversion]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdCallMetricsConversion]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[UploadConversion]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'mutateResponse/rval/value[AdCallMetricsConversion]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdWordsConversionTracker]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdWordsConversionTracker]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdWordsConversionTracker]' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker',
               'mutate/operations/operand[UploadConversion]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[UploadConversion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdCallMetricsConversion]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'getResponse/rval/entries/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'mutateResponse/rval/value/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[UploadConversion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[AdWordsConversionTracker]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[UploadConversion]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201402::QuotaCheckError::Reason',
               'mutate/operations/operand[AppConversion]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201402::DatabaseError::Reason',
               'mutateResponse/rval/value[UploadConversion]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[AppConversion]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201402::DateError',
               'getResponse/rval/entries[AdCallMetricsConversion]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201402::ClientTermsError::Reason',
               'getResponse/rval/entries[AppConversion]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[AdCallMetricsConversion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201402::InternalApiError',
               'getResponse/rval/entries[AppConversion]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[AdWordsConversionTracker]' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker',
               'mutateResponse/rval/value[UploadConversion]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[AdWordsConversionTracker]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'mutate/operations/operand[AdWordsConversionTracker]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[AdCallMetricsConversion]' => 'Google::Ads::AdWords::v201402::AdCallMetricsConversion',
               'getResponse/rval/entries[AppConversion]/appPostbackUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AppConversion]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'mutateResponse/rval/value[AppConversion]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse' => 'Google::Ads::AdWords::v201402::ConversionTrackerService::getResponse',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdWordsConversionTracker]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/trackingCodeType' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker::TrackingCodeType',
               'mutate/operations/operand[AppConversion]/appConversionType' => 'Google::Ads::AdWords::v201402::AppConversion::AppConversionType',
               'getResponse/rval/entries/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[AdWordsConversionTracker]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval' => 'Google::Ads::AdWords::v201402::ConversionTrackerPage',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201402::ClientTermsError',
               'getResponse/rval/entries[AppConversion]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[UploadConversion]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[UploadConversion]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AppConversion]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdCallMetricsConversion]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdCallMetricsConversion]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[UploadConversion]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[UploadConversion]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'getResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdWordsConversionTracker]/textFormat' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker::TextFormat',
               'getResponse/rval/entries[UploadConversion]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'mutate/operations/operand[AdWordsConversionTracker]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdWordsConversionTracker]/textFormat' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker::TextFormat',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[UploadConversion]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'mutate/operations/operand/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201402::InternalApiError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201402::RejectedError::Reason',
               'getResponse/rval/entries[AdCallMetricsConversion]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AppConversion]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdCallMetricsConversion]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[UploadConversion]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'mutate/operations/operand[AppConversion]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[AdCallMetricsConversion]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201402::SelectorError::Reason',
               'mutateResponse/rval/value[AppConversion]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201402::DatabaseError',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201402::AuthorizationError',
               'mutateResponse/rval/value[AppConversion]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[AppConversion]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[AppConversion]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdWordsConversionTracker]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[AdCallMetricsConversion]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[UploadConversion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201402::Operator',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[UploadConversion]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[AdCallMetricsConversion]/phoneCallDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[AdWordsConversionTracker]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[UploadConversion]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201402::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AppConversion]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutateResponse/rval/value/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[AppConversion]/appConversionType' => 'Google::Ads::AdWords::v201402::AppConversion::AppConversionType',
               'mutateResponse/rval/value[AppConversion]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdWordsConversionTracker]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdCallMetricsConversion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[AdCallMetricsConversion]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'mutateResponse/rval/value[AppConversion]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'mutateResponse/rval/value/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdWordsConversionTracker]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AppConversion]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AppConversion]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[UploadConversion]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[UploadConversion]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'mutateResponse/rval/value[AdWordsConversionTracker]/backgroundColor' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdCallMetricsConversion]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdCallMetricsConversion]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'mutateResponse/rval/value[AppConversion]' => 'Google::Ads::AdWords::v201402::AppConversion',
               'mutate/operations/operand[AppConversion]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201402::RangeError::Reason',
               'mutateResponse/rval/value/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[AdWordsConversionTracker]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201402::ReadOnlyError',
               'mutate/operations/operand[UploadConversion]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdCallMetricsConversion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdCallMetricsConversion]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201402::RequestError',
               'getResponse/rval/entries/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[UploadConversion]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[UploadConversion]' => 'Google::Ads::AdWords::v201402::UploadConversion',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201402::RequiredError',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[AppConversion]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdWordsConversionTracker]/backgroundColor' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201402::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201402::NotEmptyError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdCallMetricsConversion]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdWordsConversionTracker]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdCallMetricsConversion]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ConversionTrackingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[UploadConversion]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[UploadConversion]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[UploadConversion]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[UploadConversion]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdWordsConversionTracker]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'getResponse/rval/entries[AppConversion]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201402::AuthenticationError::Reason',
               'mutateResponse/rval/value[AppConversion]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[AdCallMetricsConversion]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdCallMetricsConversion]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[UploadConversion]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[AdWordsConversionTracker]' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201402::StringLengthError::Reason',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse' => 'Google::Ads::AdWords::v201402::ConversionTrackerService::mutateResponse',
               'mutateResponse/rval/value[AppConversion]/appPlatform' => 'Google::Ads::AdWords::v201402::AppConversion::AppPlatform',
               'getResponse/rval/entries[AdCallMetricsConversion]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[AdCallMetricsConversion]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[UploadConversion]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AppConversion]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AppConversion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201402::OperatorError::Reason',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[UploadConversion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdCallMetricsConversion]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdWordsConversionTracker]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[AdCallMetricsConversion]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AppConversion]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[UploadConversion]' => 'Google::Ads::AdWords::v201402::UploadConversion',
               'mutateResponse/rval/value[AdWordsConversionTracker]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'mutateResponse/rval/value/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'mutateResponse/rval/value[AdCallMetricsConversion]/phoneCallDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201402::DateRange',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201402::SortOrder',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdWordsConversionTracker]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdCallMetricsConversion]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[AdCallMetricsConversion]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get' => 'Google::Ads::AdWords::v201402::ConversionTrackerService::get',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutateResponse/rval/value[AdCallMetricsConversion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdCallMetricsConversion]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201402::QuotaCheckError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdCallMetricsConversion]' => 'Google::Ads::AdWords::v201402::AdCallMetricsConversion',
               'getResponse/rval/entries[AdWordsConversionTracker]/conversionPageLanguage' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[AppConversion]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AppConversion]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'getResponse/rval/entries[AdCallMetricsConversion]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[AdCallMetricsConversion]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdWordsConversionTracker]/markupLanguage' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker::MarkupLanguage',
               'getResponse/rval/entries[UploadConversion]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'getResponse/rval/entries[AdCallMetricsConversion]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdCallMetricsConversion]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[AppConversion]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201402::StringLengthError',
               'mutate/operations/operand[AppConversion]/appPostbackUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[UploadConversion]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[UploadConversion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdCallMetricsConversion]/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[UploadConversion]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[AdWordsConversionTracker]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[AppConversion]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdCallMetricsConversion]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'mutate/operations/operand[AdWordsConversionTracker]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[AdWordsConversionTracker]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[AdWordsConversionTracker]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdWordsConversionTracker]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdCallMetricsConversion]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201402::DistinctError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[UploadConversion]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[UploadConversion]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'getResponse/rval/entries[UploadConversion]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ConversionTrackingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[UploadConversion]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AppConversion]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[UploadConversion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[AppConversion]/appPostbackUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ConversionTrackingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[UploadConversion]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'Fault/detail/ApiExceptionFault/errors[ConversionTrackingError]/reason' => 'Google::Ads::AdWords::v201402::ConversionTrackingError::Reason',
               'getResponse/rval/entries[AdCallMetricsConversion]/stats/conversionValue/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[UploadConversion]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'getResponse/rval/entries[AdWordsConversionTracker]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[AdWordsConversionTracker]/conversionPageLanguage' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AppConversion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdWordsConversionTracker]/trackingCodeType' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker::TrackingCodeType',
               'mutateResponse/rval/value[UploadConversion]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'getResponse/rval/entries[AppConversion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[AdWordsConversionTracker]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[AdWordsConversionTracker]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[AdWordsConversionTracker]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AppConversion]/appConversionType' => 'Google::Ads::AdWords::v201402::AppConversion::AppConversionType',
               'getResponse/rval/entries[AppConversion]' => 'Google::Ads::AdWords::v201402::AppConversion',
               'mutate/operations/operand[AppConversion]/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[UploadConversion]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[AdCallMetricsConversion]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[AdWordsConversionTracker]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[AdCallMetricsConversion]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[AdWordsConversionTracker]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'getResponse/rval/entries/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201402::RangeError',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AppConversion]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdWordsConversionTracker]/backgroundColor' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201402::OrderBy',
               'mutateResponse/rval/value[AdWordsConversionTracker]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[UploadConversion]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'mutateResponse/rval/value[AdCallMetricsConversion]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdWordsConversionTracker]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201402::RequiredError::Reason',
               'mutate/operations/operand/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AppConversion]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdCallMetricsConversion]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdWordsConversionTracker]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'mutateResponse/rval/value/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/numConversionEvents' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201402::ReadOnlyError::Reason',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201402::IdError::Reason',
               'mutateResponse/rval/value[AdCallMetricsConversion]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[AdWordsConversionTracker]/textFormat' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker::TextFormat',
               'mutate/operations/operand[AdWordsConversionTracker]/trackingCodeType' => 'Google::Ads::AdWords::v201402::AdWordsConversionTracker::TrackingCodeType',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'getResponse/rval/entries[AppConversion]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate' => 'Google::Ads::AdWords::v201402::ConversionTrackerService::mutate',
               'mutateResponse/rval/value[AdWordsConversionTracker]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[UploadConversion]/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdCallMetricsConversion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[AdWordsConversionTracker]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[AdWordsConversionTracker]/alwaysUseDefaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[AdCallMetricsConversion]/stats' => 'Google::Ads::AdWords::v201402::ConversionTrackerStats',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201402::SizeLimitError::Reason',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/productAdsChargeableConversionWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[UploadConversion]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdCallMetricsConversion]/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[AppConversion]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[AdCallMetricsConversion]/ctcLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'getResponse/rval/entries[AdWordsConversionTracker]/category' => 'Google::Ads::AdWords::v201402::ConversionTracker::Category',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201402::RequestError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201402::DistinctError',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/defaultRevenueValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/appPlatform' => 'Google::Ads::AdWords::v201402::AppConversion::AppPlatform',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201402::IdError',
               'mutate/operations/operand[AdCallMetricsConversion]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdCallMetricsConversion]/stats/conversionValue/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[AppConversion]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201402::ConversionTrackerReturnValue',
               'mutateResponse/rval/value[AdWordsConversionTracker]/isProductAdsChargeable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201402::OperationAccessDenied::Reason',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdCallMetricsConversion]/phoneCallDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/viewthroughLookbackWindow' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/countingType' => 'Google::Ads::AdWords::v201402::ConversionDeduplicationMode',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201402::ConversionTracker',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201402::RejectedError',
               'getResponse/rval/entries[UploadConversion]/status' => 'Google::Ads::AdWords::v201402::ConversionTracker::Status',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]' => 'Google::Ads::AdWords::v201402::OperatorError',
               'mutateResponse/rval/value[AdWordsConversionTracker]/ConversionTracker.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AppConversion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[AdWordsConversionTracker]/stats/numConvertedClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[AdWordsConversionTracker]/conversionPageLanguage' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201402::Selector',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201402::ConversionTracker',
               'mutateResponse/rval/value[AppConversion]/stats/mostRecentConversionDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[AdWordsConversionTracker]/stats/conversionValue' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[AppConversion]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201402::SelectorError',
               'mutate/operations' => 'Google::Ads::AdWords::v201402::ConversionTrackerOperation'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201402::TypeMaps::ConversionTrackerService - typemap for ConversionTrackerService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

