
package Google::Ads::AdWords::v201402::TypeMaps::MediaService;
use strict;
use warnings;

our $typemap_1 = {
               'Fault/detail/ApiExceptionFault/errors[VideoError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201402::EntityNotFound::Reason',
               'uploadResponse/rval/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'getResponse/rval/entries[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201402::Predicate',
               'getResponse/rval/entries[Audio]' => 'Google::Ads::AdWords::v201402::Audio',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201402::NotEmptyError::Reason',
               'uploadResponse/rval[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[Video]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'queryResponse/rval/entries[Image]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'queryResponse/rval/entries[Video]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201402::RateExceededError::Reason',
               'getResponse/rval/entries[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201402::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201402::Paging',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201402::NewEntityCreationError',
               'uploadResponse/rval[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Audio]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'upload/media[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201402::Media',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'getResponse/rval/entries[Image]' => 'Google::Ads::AdWords::v201402::Image',
               'upload/media[Audio]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]' => 'Google::Ads::AdWords::v201402::Audio',
               'uploadResponse/rval[Video]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'upload/media/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'uploadResponse/rval[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201402::Predicate::Operator',
               'queryResponse/rval/entries/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[AudioError]' => 'Google::Ads::AdWords::v201402::AudioError',
               'queryResponse/rval/entries/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201402::OperationAccessDenied',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[QueryError]' => 'Google::Ads::AdWords::v201402::QueryError',
               'uploadResponse/rval[Image]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'getResponse/rval/entries[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201402::RateExceededError',
               'getResponse/rval/entries[Video]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'uploadResponse/rval[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[VideoError]' => 'Google::Ads::AdWords::v201402::VideoError',
               'queryResponse/rval/entries[Audio]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ImageError]' => 'Google::Ads::AdWords::v201402::ImageError',
               'getResponse/rval/entries[Audio]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'upload/media[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Video]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'uploadResponse/rval[Video]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'queryResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'uploadResponse/rval[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'upload/media[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'uploadResponse/rval[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'getResponse/rval/entries[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'upload/media[Video]' => 'Google::Ads::AdWords::v201402::Video',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201402::QuotaCheckError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201402::DatabaseError::Reason',
               'uploadResponse/rval/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'uploadResponse/rval[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Image]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'uploadResponse/rval[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201402::ClientTermsError::Reason',
               'upload/media/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201402::InternalApiError',
               'queryResponse/rval/entries[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Audio]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'getResponse/rval/entries[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Audio]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'getResponse' => 'Google::Ads::AdWords::v201402::MediaService::getResponse',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'uploadResponse/rval[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval' => 'Google::Ads::AdWords::v201402::MediaPage',
               'queryResponse/rval/entries[Video]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201402::ClientTermsError',
               'getResponse/rval/entries/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Image]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'upload/media[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Image]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'upload/media[Image]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'getResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Image]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'getResponse/rval/entries[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AudioError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries' => 'Google::Ads::AdWords::v201402::Media',
               'getResponse/rval/entries[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201402::InternalApiError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201402::RejectedError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Image]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'getResponse/rval/entries[Video]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'upload/media[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Image]' => 'Google::Ads::AdWords::v201402::Image',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'getResponse/rval/entries[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'uploadResponse/rval[Video]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'uploadResponse/rval[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[VideoError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201402::SelectorError::Reason',
               'uploadResponse/rval[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201402::DatabaseError',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201402::AuthorizationError',
               'upload/media[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'upload/media[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Audio]' => 'Google::Ads::AdWords::v201402::Audio',
               'queryResponse/rval/entries[Audio]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'queryResponse/rval/entries[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload' => 'Google::Ads::AdWords::v201402::MediaService::upload',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Image]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'uploadResponse/rval[Video]' => 'Google::Ads::AdWords::v201402::Video',
               'query' => 'Google::Ads::AdWords::v201402::MediaService::query',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201402::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'uploadResponse/rval[Audio]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse' => 'Google::Ads::AdWords::v201402::MediaService::uploadResponse',
               'uploadResponse/rval[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'upload/media[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'queryResponse/rval/entries[Video]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'uploadResponse/rval[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse' => 'Google::Ads::AdWords::v201402::MediaService::queryResponse',
               'Fault/detail/ApiExceptionFault/errors[AudioError]/reason' => 'Google::Ads::AdWords::v201402::AudioError::Reason',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Video]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201402::NewEntityCreationError::Reason',
               'queryResponse/rval/entries[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Video]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'uploadResponse/rval/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Image]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'uploadResponse/rval/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'queryResponse/rval/entries[Audio]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'uploadResponse/rval/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[Image]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media' => 'Google::Ads::AdWords::v201402::Media',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'upload/media[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'upload/media[Image]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'getResponse/rval/entries[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201402::RangeError::Reason',
               'queryResponse/rval/entries/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201402::ReadOnlyError',
               'uploadResponse/rval[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201402::RequestError',
               'uploadResponse/rval[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201402::RequiredError',
               'getResponse/rval/entries[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201402::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201402::NotEmptyError',
               'upload/media[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Image]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval' => 'Google::Ads::AdWords::v201402::Media',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[Audio]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'getResponse/rval/entries[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'uploadResponse/rval[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201402::AuthenticationError::Reason',
               'uploadResponse/rval[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AudioError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'uploadResponse/rval[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[Video]' => 'Google::Ads::AdWords::v201402::Video',
               'uploadResponse/rval/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'uploadResponse/rval[Image]' => 'Google::Ads::AdWords::v201402::Image',
               'uploadResponse/rval[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201402::StringLengthError::Reason',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Audio]' => 'Google::Ads::AdWords::v201402::Audio',
               'upload/media/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[Image]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'getResponse/rval/entries[Video]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'queryResponse/rval/entries[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]' => 'Google::Ads::AdWords::v201402::Video',
               'uploadResponse/rval[Video]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'queryResponse/rval/entries[Image]' => 'Google::Ads::AdWords::v201402::Image',
               'queryResponse/rval/entries/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'getResponse/rval/entries[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Audio]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'queryResponse/rval/entries[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Image]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'upload/media[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201402::DateRange',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201402::SortOrder',
               'uploadResponse/rval[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'getResponse/rval/entries[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get' => 'Google::Ads::AdWords::v201402::MediaService::get',
               'uploadResponse/rval[Audio]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'getResponse/rval/entries[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[Video]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'queryResponse/rval/entries[Image]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[VideoError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201402::QuotaCheckError',
               'upload/media[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'getResponse/rval/entries/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Image]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'getResponse/rval/entries[Video]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'upload/media[Audio]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'getResponse/rval/entries[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval/entries/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201402::StringLengthError',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201402::EntityNotFound',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/reason' => 'Google::Ads::AdWords::v201402::ImageError::Reason',
               'Fault/detail/ApiExceptionFault/errors[MediaError]' => 'Google::Ads::AdWords::v201402::MediaError',
               'getResponse/rval/entries/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'getResponse/rval/entries[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Image]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201402::QueryError::Reason',
               'queryResponse/rval/entries[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'uploadResponse/rval/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'getResponse/rval/entries/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'uploadResponse/rval[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201402::DistinctError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'uploadResponse/rval/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'uploadResponse/rval/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Image]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'queryResponse/rval/entries[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[AudioError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'getResponse/rval/entries[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201402::NullError',
               'getResponse/rval/entries[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'upload/media[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'upload/media[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval' => 'Google::Ads::AdWords::v201402::MediaPage',
               'upload/media[Video]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'queryResponse/rval/entries[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Video]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'Fault/detail/ApiExceptionFault/errors[VideoError]/reason' => 'Google::Ads::AdWords::v201402::VideoError::Reason',
               'uploadResponse/rval/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'getResponse/rval/entries[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'upload/media[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'upload/media[Video]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'getResponse/rval/entries[Image]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'uploadResponse/rval[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201402::RangeError',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'getResponse/rval/entries[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'getResponse/rval/entries[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'getResponse/rval/entries[Video]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201402::OrderBy',
               'upload/media[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'uploadResponse/rval[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/reason' => 'Google::Ads::AdWords::v201402::MediaError::Reason',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Video]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[VideoError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201402::RequiredError::Reason',
               'upload/media/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Image]/dimensions/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Image]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201402::ReadOnlyError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201402::NullError::Reason',
               'getResponse/rval/entries[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201402::IdError::Reason',
               'uploadResponse/rval[Image]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[AudioError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'uploadResponse/rval[Audio]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'getResponse/rval/entries[Audio]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'uploadResponse/rval[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[Image]/urls' => 'Google::Ads::AdWords::v201402::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'upload/media[Image]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'getResponse/rval/entries[Image]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'upload/media/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'upload/media[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201402::SizeLimitError::Reason',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201402::RequestError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201402::DistinctError',
               'upload/media/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Audio]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'upload/media[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Video]/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201402::IdError',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'query/query' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201402::OperationAccessDenied::Reason',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'upload/media[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'queryResponse/rval/entries/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201402::RejectedError',
               'getResponse/rval/entries[Audio]/urls/key' => 'Google::Ads::AdWords::v201402::Media::Size',
               'upload/media[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'uploadResponse/rval[Image]/type' => 'Google::Ads::AdWords::v201402::Media::MediaType',
               'upload/media[Video]/dimensions/value' => 'Google::Ads::AdWords::v201402::Dimensions',
               'uploadResponse/rval[Image]/dimensions' => 'Google::Ads::AdWords::v201402::Media_Size_DimensionsMapEntry',
               'upload/media[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201402::Selector',
               'upload/media/mimeType' => 'Google::Ads::AdWords::v201402::Media::MimeType',
               'uploadResponse/rval[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'upload/media/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201402::SelectorError',
               'uploadResponse/rval[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201402::TypeMaps::MediaService - typemap for MediaService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

