
package Google::Ads::AdWords::v201309::TypeMaps::AdwordsUserListService;
use strict;
use warnings;

our $typemap_1 = {
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'mutateResponse/rval/value[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201309::UserList',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BasicUserList]' => 'Google::Ads::AdWords::v201309::BasicUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201309::Predicate',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BasicUserList]/conversionTypes' => 'Google::Ads::AdWords::v201309::UserListConversionType',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'mutateResponse/rval/value/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201309::LogicalUserListOperand',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BasicUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201309::UserListConversionType::Category',
               'mutateResponse/rval/value[BasicUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201309::UserListConversionType::Category',
               'getResponse/rval/entries[BasicUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'mutate/operations/operand/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201309::Paging',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes' => 'Google::Ads::AdWords::v201309::UserListConversionType',
               'mutate/operations/operand[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201309::UserListLogicalRule::Operator',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201309::UserList',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutateResponse/rval/value/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]' => 'Google::Ads::AdWords::v201309::BasicUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/reason' => 'Google::Ads::AdWords::v201309::CollectionSizeError::Reason',
               'mutate/operations/operand[BasicUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201309::UserListConversionType::Category',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201309::UserListLogicalRule',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201309::UserList',
               'mutateResponse/rval/value/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201309::Predicate::Operator',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201309::UserListLogicalRule',
               'mutateResponse/rval/value/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/reason' => 'Google::Ads::AdWords::v201309::UserListError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BasicUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'getResponse/rval/entries[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BasicUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201309::LogicalUserListOperand',
               'mutate/operations/operand[BasicUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[BasicUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BasicUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201309::UserListLogicalRule',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201309::LogicalUserListOperand',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BasicUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BasicUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[ExternalRemarketingUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]' => 'Google::Ads::AdWords::v201309::BasicUserList',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201309::UserListConversionType::Category',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'getResponse' => 'Google::Ads::AdWords::v201309::AdwordsUserListService::getResponse',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201309::UserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BasicUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BasicUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BasicUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201309::UserListLogicalRule',
               'mutate/operations/operand[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval' => 'Google::Ads::AdWords::v201309::UserListPage',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201309::ExternalRemarketingUserList',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BasicUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201309::ExternalRemarketingUserList',
               'getResponse/rval/entries[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]' => 'Google::Ads::AdWords::v201309::BasicUserList',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'getResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201309::UserListConversionType::Category',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BasicUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201309::UserList',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BasicUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201309::UserListConversionType::Category',
               'mutateResponse/rval/value[LogicalUserList]' => 'Google::Ads::AdWords::v201309::LogicalUserList',
               'mutate/operations/operand[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'mutate/operations/operand[BasicUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201309::ExternalRemarketingUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BasicUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes' => 'Google::Ads::AdWords::v201309::UserListConversionType',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BasicUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BasicUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201309::ExternalRemarketingUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BasicUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[BasicUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[BasicUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'getResponse/rval/entries[BasicUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201309::UserListLogicalRule::Operator',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]' => 'Google::Ads::AdWords::v201309::CollectionSizeError',
               'getResponse/rval/entries[LogicalUserList]' => 'Google::Ads::AdWords::v201309::LogicalUserList',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'mutateResponse/rval/value[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]' => 'Google::Ads::AdWords::v201309::LogicalUserList',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BasicUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[BasicUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201309::UserListLogicalRule::Operator',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]' => 'Google::Ads::AdWords::v201309::LogicalUserList',
               'getResponse/rval/entries[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201309::UserListLogicalRule',
               'getResponse/rval/entries/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'mutate/operations/operand[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]' => 'Google::Ads::AdWords::v201309::BasicUserList',
               'getResponse/rval/entries[ExternalRemarketingUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BasicUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BasicUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201309::LogicalUserListOperand',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse' => 'Google::Ads::AdWords::v201309::AdwordsUserListService::mutateResponse',
               'mutate/operations/operand[BasicUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201309::UserListLogicalRule::Operator',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'getResponse/rval/entries[BasicUserList]/conversionTypes' => 'Google::Ads::AdWords::v201309::UserListConversionType',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201309::UserListConversionType::Category',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[ExternalRemarketingUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BasicUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[BasicUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201309::DateRange',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201309::SortOrder',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'get' => 'Google::Ads::AdWords::v201309::AdwordsUserListService::get',
               'mutate/operations/operand[LogicalUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201309::UserListLogicalRule::Operator',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201309::ExternalRemarketingUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes' => 'Google::Ads::AdWords::v201309::UserListConversionType',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'mutateResponse/rval/value[BasicUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201309::UserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[BasicUserList]' => 'Google::Ads::AdWords::v201309::BasicUserList',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BasicUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[ExternalRemarketingUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201309::LogicalUserListOperand',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'getResponse/rval/entries[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201309::ExternalRemarketingUserList',
               'mutate/operations/operand[BasicUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BasicUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201309::UserListConversionType::Category',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201309::UserListConversionType::Category',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutate/operations/operand[BasicUserList]' => 'Google::Ads::AdWords::v201309::BasicUserList',
               'getResponse/rval/entries[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]' => 'Google::Ads::AdWords::v201309::LogicalUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201309::ExternalRemarketingUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BasicUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BasicUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutate/operations/operand/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BasicUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[BasicUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201309::OrderBy',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]' => 'Google::Ads::AdWords::v201309::LogicalUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BasicUserList]/conversionTypes' => 'Google::Ads::AdWords::v201309::UserListConversionType',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201309::UserList',
               'getResponse/rval/entries/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[BasicUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BasicUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes' => 'Google::Ads::AdWords::v201309::UserListConversionType',
               'mutate' => 'Google::Ads::AdWords::v201309::AdwordsUserListService::mutate',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes' => 'Google::Ads::AdWords::v201309::UserListConversionType',
               'getResponse/rval/entries/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BasicUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201309::AccessReason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[BasicUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'getResponse/rval/entries/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'mutateResponse/rval/value[BasicUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201309::UserListLogicalRule',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201309::LogicalUserListOperand',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BasicUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeForSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BasicUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'getResponse/rval/entries[BasicUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[UserListError]' => 'Google::Ads::AdWords::v201309::UserListError',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201309::UserListLogicalRule::Operator',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201309::ExternalRemarketingUserList',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201309::UserListReturnValue',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'mutate/operations/operand[ExternalRemarketingUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BasicUserList]/sizeRange' => 'Google::Ads::AdWords::v201309::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201309::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201309::UserList',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BasicUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]' => 'Google::Ads::AdWords::v201309::BasicUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeRangeForSearch' => 'Google::Ads::AdWords::v201309::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201309::ExternalRemarketingUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]/conversionTypes' => 'Google::Ads::AdWords::v201309::UserListConversionType',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201309::Selector',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201309::UserList',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[BasicUserList]' => 'Google::Ads::AdWords::v201309::BasicUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201309::AccountUserListStatus',
               'mutate/operations/operand/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'getResponse/rval/entries[BasicUserList]/integrationCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations' => 'Google::Ads::AdWords::v201309::UserListOperation'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201309::TypeMaps::AdwordsUserListService - typemap for AdwordsUserListService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

