
package Google::Ads::AdWords::v201309::TypeMaps::MutateJobService;
use strict;
use warnings;

our $typemap_1 = {
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]' => 'Google::Ads::AdWords::v201309::RejectedError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[LostResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/history[BulkMutateJobEvent]/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'get/selector[BulkMutateJobSelector]/includeHistory' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/scheduling/feedItemSchedules/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[SimpleMutateJob]/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/errors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[SimpleMutateJob]/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/status' => 'Google::Ads::AdWords::v201309::FeedItem::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResult/selector/includeStats' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues' => 'Google::Ads::AdWords::v201309::FeedItemAttributeValue',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand' => 'Google::Ads::AdWords::v201309::TargetList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]' => 'Google::Ads::AdWords::v201309::AdScheduleTargetList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling' => 'Google::Ads::AdWords::v201309::FeedItemScheduling',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationErrors' => 'Google::Ads::AdWords::v201309::FeedItemAttributeError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]' => 'Google::Ads::AdWords::v201309::BudgetError',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]' => 'Google::Ads::AdWords::v201309::BudgetError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/reason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'mutateResponse/rval/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/devicePreference' => 'Google::Ads::AdWords::v201309::FeedItemDevicePreference',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]' => 'Google::Ads::AdWords::v201309::BudgetError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/frequencyCap/level' => 'Google::Ads::AdWords::v201309::Level',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]' => 'Google::Ads::AdWords::v201309::BudgetOperation',
               'getResponse/rval[SimpleMutateJob]/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]' => 'Google::Ads::AdWords::v201309::BudgetOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]' => 'Google::Ads::AdWords::v201309::BudgetError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Media/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]' => 'Google::Ads::AdWords::v201309::CampaignCriterionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201309::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[BudgetOperation]/operand/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201309::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/endTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]' => 'Google::Ads::AdWords::v201309::AdError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/integerValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/validationDetails/validationErrors' => 'Google::Ads::AdWords::v201309::FeedItemAttributeError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/targets/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutateResponse/rval/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request' => 'Google::Ads::AdWords::v201309::BulkMutateRequest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/numRequestParts' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause' => 'Google::Ads::AdWords::v201309::ApiException',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/status' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::Status',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]' => 'Google::Ads::AdWords::v201309::BulkMutateJob',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/contentBidCriterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]' => 'Google::Ads::AdWords::v201309::AdError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupCriterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo' => 'Google::Ads::AdWords::v201309::OverrideInfo',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]' => 'Google::Ads::AdWords::v201309::CampaignTargetOperation',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutate/operations[AdGroupOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/endTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/targets/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]' => 'Google::Ads::AdWords::v201309::FailureResult',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201309::AdServingOptimizationStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/partIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupExperimentData',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]' => 'Google::Ads::AdWords::v201309::FailureResult',
               'getResponse/rval[SimpleMutateJob]/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/endTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/feedItemId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201309::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/errors[SettingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/startTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingTransitionError]/reason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/devicePreference' => 'Google::Ads::AdWords::v201309::FeedItemDevicePreference',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201309::AdGroupExperimentBidMultipliers',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupServiceError]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo' => 'Google::Ads::AdWords::v201309::OverrideInfo',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupExperimentData',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup' => 'Google::Ads::AdWords::v201309::AdGroup',
               'mutateResponse/rval/history[BulkMutateJobEvent]' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterionExperimentData',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors' => 'Google::Ads::AdWords::v201309::FeedItemAttributeError',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationErrors' => 'Google::Ads::AdWords::v201309::FeedItemAttributeError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/status' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupExperimentData',
               'getResultResponse/rval/SimpleMutateResult/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]' => 'Google::Ads::AdWords::v201309::AdScheduleTargetList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]' => 'Google::Ads::AdWords::v201309::BulkMutateJob',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/targets' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[FeedItemOperation]/operand/endTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupExperimentBidMultipliers',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201309::TimeUnit',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/bidModifierSource' => 'Google::Ads::AdWords::v201309::BidModifierSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]' => 'Google::Ads::AdWords::v201309::SettingError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::Status',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/reason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations[AdGroupCriterionOperation]/operand/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]' => 'Google::Ads::AdWords::v201309::BiddingTransitionError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]' => 'Google::Ads::AdWords::v201309::CampaignError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingTransitionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPMAdGroupExperimentBidMultipliers',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::Status',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors/feedAttributeIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations' => 'Google::Ads::AdWords::v201309::Operation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/partIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Target/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/reason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/JobSelector.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResponse/rval[SimpleMutateJob]/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201309::MultiplierSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/scopingEntityId/type' => 'Google::Ads::AdWords::v201309::EntityId::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/policy' => 'Google::Ads::AdWords::v201309::BulkMutateJobPolicy',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/errors[BulkMutateJobError]' => 'Google::Ads::AdWords::v201309::BulkMutateJobError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[BudgetOperation]/operand/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/reason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media' => 'Google::Ads::AdWords::v201309::Media',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingErrors]' => 'Google::Ads::AdWords::v201309::BiddingErrors',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::Status',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignTargetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[SimpleMutateJob]/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResponse/rval[SimpleMutateJob]/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[SimpleMutateJob]/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/reason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/errors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility::RejectionReason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutateResponse/rval/history' => 'Google::Ads::AdWords::v201309::JobEvent',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Media/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupCriterion',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[FeedItemOperation]/operand/startTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/scheduling/feedItemSchedules/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/status' => 'Google::Ads::AdWords::v201309::CampaignStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]' => 'Google::Ads::AdWords::v201309::FeedItemOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/reason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'mutateResponse/rval/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201309::UserStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResponse/rval[SimpleMutateJob]/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues' => 'Google::Ads::AdWords::v201309::FeedItemAttributeValue',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]' => 'Google::Ads::AdWords::v201309::AdGroupOperation',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201309::SystemServingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension' => 'Google::Ads::AdWords::v201309::CampaignAdExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]' => 'Google::Ads::AdWords::v201309::CampaignCriterionError',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility::RejectionReason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaError]' => 'Google::Ads::AdWords::v201309::QuotaError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues' => 'Google::Ads::AdWords::v201309::FeedItemAttributeValue',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201309::AdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]' => 'Google::Ads::AdWords::v201309::QuotaError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201309::QualityInfo',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/reason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations[AdGroupAdOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201309::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignAdExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations[BudgetOperation]/operand/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/reason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[JobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]' => 'Google::Ads::AdWords::v201309::RejectedError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[BatchFailureResult]' => 'Google::Ads::AdWords::v201309::BatchFailureResult',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/scopingEntityId' => 'Google::Ads::AdWords::v201309::EntityId',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]' => 'Google::Ads::AdWords::v201309::FailureResult',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/reason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]' => 'Google::Ads::AdWords::v201309::AdGroupServiceError',
               'getResultResponse/rval/SimpleMutateResult/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'getResponse/rval/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]' => 'Google::Ads::AdWords::v201309::AdGroupAdError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/numRequestPartsReceived' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignTargetOperation]' => 'Google::Ads::AdWords::v201309::CampaignTargetOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Media/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[MediaError]/reason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResponse/rval[BulkMutateJob]/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[SimpleMutateJob]/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]' => 'Google::Ads::AdWords::v201309::AdGroupAdOperation',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[FeedItemError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[FeedItemError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/history[BulkMutateJobEvent]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]' => 'Google::Ads::AdWords::v201309::BudgetOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors' => 'Google::Ads::AdWords::v201309::FeedItemAttributeError',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operand/validationDetails/validationErrors' => 'Google::Ads::AdWords::v201309::FeedItemAttributeError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules' => 'Google::Ads::AdWords::v201309::FeedItemSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ValidationStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201309::AdGroupExperimentBidMultipliers',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201309::MultiplierSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/feedItemId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdError]' => 'Google::Ads::AdWords::v201309::AdGroupAdError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupServiceError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[CampaignCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'mutate/operations[AdGroupAdOperation]/operand/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[SimpleMutateJob]/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/reason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationErrors/feedAttributeIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/endTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/reason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules' => 'Google::Ads::AdWords::v201309::FeedItemSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterionExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules' => 'Google::Ads::AdWords::v201309::FeedItemSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]' => 'Google::Ads::AdWords::v201309::AdGroupBidModifierOperation',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations[FeedItemOperation]/operand/attributeValues/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/startTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors/validationErrorCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201309::AdGroupCriterionExperimentBidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'mutate/operations[AdGroupOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]' => 'Google::Ads::AdWords::v201309::AdGroupAdError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/partIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'Fault/detail/ApiExceptionFault/errors[AdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap/level' => 'Google::Ads::AdWords::v201309::Level',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/startTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201309::AdGroupCriterionExperimentBidMultiplier',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/numRequestPartsReceived' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::NegativeAdGroupCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupAdCountLimitExceeded',
               'mutate/operations[CampaignTargetOperation]/operand/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand' => 'Google::Ads::AdWords::v201309::Budget',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/feedMappingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]' => 'Google::Ads::AdWords::v201309::JobError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdExtensionOverrideOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operand/devicePreference/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BudgetError]/reason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/history[BulkMutateJobEvent]' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignAdExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]' => 'Google::Ads::AdWords::v201309::CampaignCriterionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[SettingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[SimpleMutateJob]/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse' => 'Google::Ads::AdWords::v201309::MutateJobService::mutateResponse',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[BudgetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[JobError]/reason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResponse/rval/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/scheduling/feedItemSchedules' => 'Google::Ads::AdWords::v201309::FeedItemSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201309::AdServingOptimizationStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup' => 'Google::Ads::AdWords::v201309::AdGroup',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'mutate/operations[AdGroupOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResponse/rval[SimpleMutateJob]/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[BatchFailureResult]/operationIndexInBatch' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]' => 'Google::Ads::AdWords::v201309::AdGroupAdOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling' => 'Google::Ads::AdWords::v201309::FeedItemScheduling',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/status' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::Status',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[CampaignAdExtensionError]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/validationDetails/validationErrors/validationErrorCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroup::Status',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/status' => 'Google::Ads::AdWords::v201309::FeedItem::Status',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/errors[BulkMutateJobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]' => 'Google::Ads::AdWords::v201309::FeedItemError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/devicePreference/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/policy/prerequisiteJobIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]' => 'Google::Ads::AdWords::v201309::BiddingError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201309::UserStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]' => 'Google::Ads::AdWords::v201309::FeedItemError',
               'getResultResponse/rval/SimpleMutateResult/results/Job/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[ImageError]' => 'Google::Ads::AdWords::v201309::ImageError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/status' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]' => 'Google::Ads::AdWords::v201309::AdGroupServiceError',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[SimpleMutateJob]/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AdError]' => 'Google::Ads::AdWords::v201309::AdError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]' => 'Google::Ads::AdWords::v201309::CampaignError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/validationDetails' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]' => 'Google::Ads::AdWords::v201309::TargetError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]' => 'Google::Ads::AdWords::v201309::CampaignOperation',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]' => 'Google::Ads::AdWords::v201309::BiddingTransitionError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResult/selector' => 'Google::Ads::AdWords::v201309::JobSelector',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignAdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[SimpleMutateJob]/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList' => 'Google::Ads::AdWords::v201309::TargetList',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterionExperimentData',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[SimpleMutateJob]/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroup::Status',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo::RadiusUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]' => 'Google::Ads::AdWords::v201309::BudgetError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]' => 'Google::Ads::AdWords::v201309::AdExtensionError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[SimpleMutateJob]/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201309::AdGroupCriterionExperimentBidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup' => 'Google::Ads::AdWords::v201309::AdGroup',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/reason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroup::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPMAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[BudgetOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201309::SystemServingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride' => 'Google::Ads::AdWords::v201309::AdExtensionOverride',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ValidationStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors/validationErrorCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignAdExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/endTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroup::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[SimpleMutateJob]/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]' => 'Google::Ads::AdWords::v201309::BiddingTransitionError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup' => 'Google::Ads::AdWords::v201309::AdGroup',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/scopingEntityId/type' => 'Google::Ads::AdWords::v201309::EntityId::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/overrideInfo' => 'Google::Ads::AdWords::v201309::OverrideInfo',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201309::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201309::AdGroupCriterionExperimentBidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem' => 'Google::Ads::AdWords::v201309::FeedItem',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201309::TimeUnit',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/numRequestParts' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResponse/rval[SimpleMutateJob]/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/SimpleMutateResult/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap' => 'Google::Ads::AdWords::v201309::FrequencyCap',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/integerValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations' => 'Google::Ads::AdWords::v201309::Operation',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Target[AdScheduleTarget]' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupExperimentBidMultipliers',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility::RejectionReason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingTransitionError]' => 'Google::Ads::AdWords::v201309::BiddingTransitionError',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]' => 'Google::Ads::AdWords::v201309::BiddingTransitionError',
               'getResultResponse/rval/SimpleMutateResult/errors[FeedItemError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SettingError]' => 'Google::Ads::AdWords::v201309::SettingError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResult/selector[BulkMutateJobSelector]/resultPartIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Target[AdScheduleTarget]/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues' => 'Google::Ads::AdWords::v201309::FeedItemAttributeValue',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/reason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]' => 'Google::Ads::AdWords::v201309::SimpleMutateJob',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'mutate/operations[AdGroupCriterionOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/reason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPMAdGroupExperimentBidMultipliers',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/devicePreference/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors' => 'Google::Ads::AdWords::v201309::FeedItemAttributeError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand' => 'Google::Ads::AdWords::v201309::Campaign',
               'getResponse/rval[BulkMutateJob]/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/reason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::NegativeAdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/servingStatus' => 'Google::Ads::AdWords::v201309::ServingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/devicePreference/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[BulkMutateJobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201309::AdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationErrors/feedAttributeIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[UnprocessedResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingTransitionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[FeedItemOperation]/operand/attributeValues/integerValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Media/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/reason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'mutate/operations[CampaignOperation]/operand/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201309::TimeUnit',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/policy' => 'Google::Ads::AdWords::v201309::BulkMutateJobPolicy',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap' => 'Google::Ads::AdWords::v201309::FrequencyCap',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201309::QualityInfo',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroup',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams' => 'Google::Ads::AdWords::v201309::OperationStream',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/history[BulkMutateJobEvent]/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion' => 'Google::Ads::AdWords::v201309::AdGroupCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201309::SystemServingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/partIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get' => 'Google::Ads::AdWords::v201309::MutateJobService::get',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignAdExtensionError]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[UnprocessedResult]' => 'Google::Ads::AdWords::v201309::UnprocessedResult',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/approvalStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Target[AdScheduleTarget]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]' => 'Google::Ads::AdWords::v201309::MediaError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201309::AdServingOptimizationStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'mutate/operations[AdGroupOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]' => 'Google::Ads::AdWords::v201309::BiddingTransitionError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201309::QualityInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[FeedItemError]' => 'Google::Ads::AdWords::v201309::FeedItemError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/history/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo::RadiusUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]' => 'Google::Ads::AdWords::v201309::ReturnValueResult',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]' => 'Google::Ads::AdWords::v201309::JobError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[SimpleMutateJob]/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults' => 'Google::Ads::AdWords::v201309::OperationStreamResult',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]' => 'Google::Ads::AdWords::v201309::BiddingErrors',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupExperimentData',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201309::UserStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand' => 'Google::Ads::AdWords::v201309::Campaign',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[JobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem' => 'Google::Ads::AdWords::v201309::FeedItem',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201309::UserStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]' => 'Google::Ads::AdWords::v201309::QuotaError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'Fault/detail/ApiExceptionFault/errors[FeedItemError]' => 'Google::Ads::AdWords::v201309::FeedItemError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/policy/prerequisiteJobIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResponse/rval[BulkMutateJob]/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/devicePreference/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201309::AdGroupExperimentBidMultipliers',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results' => 'Google::Ads::AdWords::v201309::Operand',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]' => 'Google::Ads::AdWords::v201309::FeedItemOperation',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operand/validationDetails/validationErrors/validationErrorCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionOperation',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/feedItemId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupAdCountLimitExceeded',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionError]' => 'Google::Ads::AdWords::v201309::AdExtensionError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/attributeValues/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[SimpleMutateJob]/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result' => 'Google::Ads::AdWords::v201309::BulkMutateResult',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/validationDetails/validationErrors/feedAttributeIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/servingStatus' => 'Google::Ads::AdWords::v201309::ServingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]' => 'Google::Ads::AdWords::v201309::ReturnValueResult',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'mutate/operations[AdGroupOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupExperimentData',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/status' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::Status',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]' => 'Google::Ads::AdWords::v201309::SettingError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]' => 'Google::Ads::AdWords::v201309::CampaignTargetOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201309::TimeUnit',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/approvalStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/contentBidCriterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[SimpleMutateJob]/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/approvalStatus' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/approvalStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201309::CriterionPolicyError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/integerValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/startTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/status' => 'Google::Ads::AdWords::v201309::AdGroup::Status',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling' => 'Google::Ads::AdWords::v201309::FeedItemScheduling',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupAdCountLimitExceeded',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignAdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutate/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]' => 'Google::Ads::AdWords::v201309::AdExtensionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Target[AdScheduleTarget]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResult/selector/includeHistory' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier' => 'Google::Ads::AdWords::v201309::AdGroupBidModifier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/targets/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BulkMutateJobError]' => 'Google::Ads::AdWords::v201309::BulkMutateJobError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]' => 'Google::Ads::AdWords::v201309::AdScheduleTargetList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPMAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'mutate/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo::RadiusUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]' => 'Google::Ads::AdWords::v201309::BulkMutateJob',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations[AdGroupBidModifierOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionError]' => 'Google::Ads::AdWords::v201309::CampaignCriterionError',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand' => 'Google::Ads::AdWords::v201309::TargetList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem' => 'Google::Ads::AdWords::v201309::FeedItem',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/partIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignTargetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults' => 'Google::Ads::AdWords::v201309::OperationStreamResult',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[UnprocessedResult]' => 'Google::Ads::AdWords::v201309::UnprocessedResult',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaError]/reason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignAdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/history' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201309::MultiplierSource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/PlaceHolder' => 'Google::Ads::AdWords::v201309::PlaceHolder',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[JobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]' => 'Google::Ads::AdWords::v201309::BiddingError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension' => 'Google::Ads::AdWords::v201309::CampaignAdExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/status' => 'Google::Ads::AdWords::v201309::FeedItem::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/devicePreference' => 'Google::Ads::AdWords::v201309::FeedItemDevicePreference',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operand/status' => 'Google::Ads::AdWords::v201309::FeedItem::Status',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations' => 'Google::Ads::AdWords::v201309::Operation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'Fault/detail/ApiExceptionFault/errors[AdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'mutate/operations[AdGroupAdOperation]' => 'Google::Ads::AdWords::v201309::AdGroupAdOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Target[AdScheduleTarget]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201309::SystemServingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[TargetError]' => 'Google::Ads::AdWords::v201309::TargetError',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand' => 'Google::Ads::AdWords::v201309::FeedItem',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign' => 'Google::Ads::AdWords::v201309::Campaign',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201309::MultiplierSource',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'Fault/detail/ApiExceptionFault/errors[ImageError]' => 'Google::Ads::AdWords::v201309::ImageError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams' => 'Google::Ads::AdWords::v201309::OperationStream',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap' => 'Google::Ads::AdWords::v201309::FrequencyCap',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval[SimpleMutateJob]/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[SimpleMutateJob]/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility::RejectionReason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201309::MultiplierSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201309::SystemServingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/endTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201309::AdGroupCriterionExperimentBidMultiplier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/feedItemId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/policy/prerequisiteJobIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/approvalStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap' => 'Google::Ads::AdWords::v201309::FrequencyCap',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201309::SystemServingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/contentBidCriterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo' => 'Google::Ads::AdWords::v201309::OverrideInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[SimpleMutateJob]/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]' => 'Google::Ads::AdWords::v201309::TargetError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/SimpleMutateResult/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutate/operations[AdGroupOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroup',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/feedMappingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideOperation',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingTransitionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]' => 'Google::Ads::AdWords::v201309::CampaignCriterionOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[FeedItemOperation]/operand/attributeValues/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[SimpleMutateJob]/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/devicePreference/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[SettingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201309::AdGroupCriterionExperimentBidMultiplier',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]' => 'Google::Ads::AdWords::v201309::CampaignCriterionOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupAdOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupExperimentData',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams' => 'Google::Ads::AdWords::v201309::OperationStream',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201309::UserStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility::RejectionReason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history' => 'Google::Ads::AdWords::v201309::JobEvent',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history' => 'Google::Ads::AdWords::v201309::JobEvent',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors/feedAttributeIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/reason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]' => 'Google::Ads::AdWords::v201309::BatchFailureResult',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[SimpleMutateJob]/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/reason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults' => 'Google::Ads::AdWords::v201309::OperationResult',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[UnprocessedResult]' => 'Google::Ads::AdWords::v201309::UnprocessedResult',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionError]' => 'Google::Ads::AdWords::v201309::AdExtensionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier' => 'Google::Ads::AdWords::v201309::AdGroupBidModifier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201309::TimeUnit',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[SimpleMutateJob]/history[BulkMutateJobEvent]/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[JobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'getResponse/rval[BulkMutateJob]/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[SimpleMutateJob]/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/scopingEntityId/type' => 'Google::Ads::AdWords::v201309::EntityId::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operand/attributeValues' => 'Google::Ads::AdWords::v201309::FeedItemAttributeValue',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[FeedItemOperation]/operand/scheduling' => 'Google::Ads::AdWords::v201309::FeedItemScheduling',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/frequencyCap' => 'Google::Ads::AdWords::v201309::FrequencyCap',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201309::AdGroupCriterionExperimentBidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/scopingEntityId/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[SimpleMutateJob]/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign' => 'Google::Ads::AdWords::v201309::Campaign',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/reason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/policy' => 'Google::Ads::AdWords::v201309::BulkMutateJobPolicy',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignAdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/errors[FeedItemError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdExtensionOverrideOperation]/operand' => 'Google::Ads::AdWords::v201309::AdExtensionOverride',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::NegativeAdGroupCriterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility::RejectionReason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Media/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]' => 'Google::Ads::AdWords::v201309::BiddingError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutate/operations[AdExtensionOverrideOperation]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[UnprocessedResult]' => 'Google::Ads::AdWords::v201309::UnprocessedResult',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail',
               'Fault/detail/ApiExceptionFault/errors[FeedItemError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling' => 'Google::Ads::AdWords::v201309::FeedItemScheduling',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'mutate/operations[FeedItemOperation]/operand/validationDetails/validationStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ValidationStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[JobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[JobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]' => 'Google::Ads::AdWords::v201309::CampaignTargetOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResult/selector[BulkMutateJobSelector]' => 'Google::Ads::AdWords::v201309::BulkMutateJobSelector',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]' => 'Google::Ads::AdWords::v201309::ImageError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/status' => 'Google::Ads::AdWords::v201309::FeedItem::Status',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo' => 'Google::Ads::AdWords::v201309::OverrideInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'mutate/operations[CampaignTargetOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/status' => 'Google::Ads::AdWords::v201309::FeedItem::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]' => 'Google::Ads::AdWords::v201309::CampaignOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/scopingEntityId/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]' => 'Google::Ads::AdWords::v201309::SimpleMutateJob',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/servingStatus' => 'Google::Ads::AdWords::v201309::ServingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201309::TimeUnit',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterionExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201309::AdGroupExperimentBidMultipliers',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/reason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]' => 'Google::Ads::AdWords::v201309::TargetError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]' => 'Google::Ads::AdWords::v201309::AdScheduleTargetList',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/contentBidCriterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]' => 'Google::Ads::AdWords::v201309::ImageError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/reason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterionExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'mutate/operations[AdGroupAdOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand' => 'Google::Ads::AdWords::v201309::AdExtensionOverride',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ValidationStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/history' => 'Google::Ads::AdWords::v201309::JobEvent',
               'getResponse/rval/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector[BulkMutateJobSelector]/resultPartIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[SimpleMutateJob]/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/reason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutate/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand' => 'Google::Ads::AdWords::v201309::TargetList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/servingStatus' => 'Google::Ads::AdWords::v201309::ServingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[SimpleMutateJob]/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]' => 'Google::Ads::AdWords::v201309::MediaError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/overrideInfo' => 'Google::Ads::AdWords::v201309::OverrideInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling' => 'Google::Ads::AdWords::v201309::FeedItemScheduling',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]' => 'Google::Ads::AdWords::v201309::AdGroupAdError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/contentBidCriterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[MediaError]' => 'Google::Ads::AdWords::v201309::MediaError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[FeedItemOperation]/operand/feedItemId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/reason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupExperimentBidMultipliers',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue' => 'Google::Ads::AdWords::v201309::Operand',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/level' => 'Google::Ads::AdWords::v201309::Level',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'mutateResponse/rval/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]' => 'Google::Ads::AdWords::v201309::MediaError',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201309::MultiplierSource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]' => 'Google::Ads::AdWords::v201309::FeedItemError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Target[AdScheduleTarget]/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/frequencyCap' => 'Google::Ads::AdWords::v201309::FrequencyCap',
               'mutate/operations[CampaignCriterionOperation]/operand/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]' => 'Google::Ads::AdWords::v201309::AdExtensionError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/reason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/reason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]' => 'Google::Ads::AdWords::v201309::AdGroupOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Target' => 'Google::Ads::AdWords::v201309::Target',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[LostResult]' => 'Google::Ads::AdWords::v201309::LostResult',
               'mutate/operations[CampaignOperation]/operand/servingStatus' => 'Google::Ads::AdWords::v201309::ServingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue' => 'Google::Ads::AdWords::v201309::Operand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/feedMappingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201309::AdServingOptimizationStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues' => 'Google::Ads::AdWords::v201309::FeedItemAttributeValue',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ValidationStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/reason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResult/selector[BulkMutateJobSelector]/JobSelector.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[LostResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutate/operations[FeedItemOperation]/operand/validationDetails' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupBidModifier',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules' => 'Google::Ads::AdWords::v201309::FeedItemSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/scopingEntityId' => 'Google::Ads::AdWords::v201309::EntityId',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201309::EntityAccessDenied',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Target[AdScheduleTarget]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201309::MultiplierSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/approvalStatus' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility::RejectionReason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutate/operations[CampaignAdExtensionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/history[BulkMutateJobEvent]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdError]/reason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]/operationIndexInBatch' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201309::MultiplierSource',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/status' => 'Google::Ads::AdWords::v201309::CampaignStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupAdOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupServiceError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupAdCountLimitExceeded',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/reason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/startTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResponse/rval' => 'Google::Ads::AdWords::v201309::Job',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval[BulkMutateJob]/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/servingStatus' => 'Google::Ads::AdWords::v201309::ServingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand' => 'Google::Ads::AdWords::v201309::AdExtensionOverride',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo' => 'Google::Ads::AdWords::v201309::OverrideInfo',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'mutate/operations[CampaignOperation]/operand/budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/reason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]' => 'Google::Ads::AdWords::v201309::AdExtensionError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPMAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/reason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/reason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/PlaceHolder' => 'Google::Ads::AdWords::v201309::PlaceHolder',
               'mutate/operations[BudgetOperation]/operand/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201309::QualityInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupServiceError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/numRequestPartsReceived' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/bidModifierSource' => 'Google::Ads::AdWords::v201309::BidModifierSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[BudgetOperation]/operand/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate' => 'Google::Ads::AdWords::v201309::MutateJobService::mutate',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations[CampaignOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[FeedItemOperation]/operand/attributeValues/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResult/selector[BulkMutateJobSelector]/includeHistory' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]' => 'Google::Ads::AdWords::v201309::BulkMutateJobError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause' => 'Google::Ads::AdWords::v201309::ApiException',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationErrors/validationErrorCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]' => 'Google::Ads::AdWords::v201309::BudgetError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201309::EntityAccessDenied',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/status' => 'Google::Ads::AdWords::v201309::FeedItem::Status',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]' => 'Google::Ads::AdWords::v201309::FeedItemOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupBidModifier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdExtensionOverrideOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/numRequestParts' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterionExperimentData',
               'getResultResponse/rval/SimpleMutateResult/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201309::ApprovalStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]' => 'Google::Ads::AdWords::v201309::BiddingError',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history' => 'Google::Ads::AdWords::v201309::JobEvent',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPMAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand' => 'Google::Ads::AdWords::v201309::Campaign',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues' => 'Google::Ads::AdWords::v201309::FeedItemAttributeValue',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'get/selector' => 'Google::Ads::AdWords::v201309::JobSelector',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause' => 'Google::Ads::AdWords::v201309::ApiException',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/contentBidCriterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201309::UserStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201309::AdGroupCriterionExperimentBidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]/operationIndexInBatch' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupServiceError]' => 'Google::Ads::AdWords::v201309::AdGroupServiceError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResponse/rval/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResponse/rval/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]' => 'Google::Ads::AdWords::v201309::BulkMutateJobError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/numRequestPartsReceived' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]' => 'Google::Ads::AdWords::v201309::AdGroupServiceError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]' => 'Google::Ads::AdWords::v201309::AdGroupAdError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/status' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/scopingEntityId/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults' => 'Google::Ads::AdWords::v201309::OperationResult',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]' => 'Google::Ads::AdWords::v201309::AdGroupOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job' => 'Google::Ads::AdWords::v201309::Job',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupBidModifier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutate/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operand/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[BulkMutateJobError]/reason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]' => 'Google::Ads::AdWords::v201309::AdGroupAdOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/scopingEntityId/type' => 'Google::Ads::AdWords::v201309::EntityId::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[BudgetOperation]/operand/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'Fault/detail/ApiExceptionFault/errors[JobError]' => 'Google::Ads::AdWords::v201309::JobError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]' => 'Google::Ads::AdWords::v201309::FailureResult',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::Status',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Media/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/startTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap' => 'Google::Ads::AdWords::v201309::FrequencyCap',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResponse/rval/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults' => 'Google::Ads::AdWords::v201309::OperationResult',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/approvalStatus' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::ApprovalStatus',
               'Fault/detail/ApiExceptionFault/errors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::NegativeAdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201309::MultiplierSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/status' => 'Google::Ads::AdWords::v201309::FeedItem::Status',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResponse/rval[SimpleMutateJob]/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignAdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/reason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result' => 'Google::Ads::AdWords::v201309::BulkMutateResult',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues' => 'Google::Ads::AdWords::v201309::FeedItemAttributeValue',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResult/selector[BulkMutateJobSelector]/jobIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand' => 'Google::Ads::AdWords::v201309::AdExtensionOverride',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]' => 'Google::Ads::AdWords::v201309::BiddingErrors',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]' => 'Google::Ads::AdWords::v201309::CampaignCriterionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/includeHistory' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[SimpleMutateJob]/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]' => 'Google::Ads::AdWords::v201309::AdGroupAdOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors/feedAttributeIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignAdExtensionOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupAdOperation]/operand/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]' => 'Google::Ads::AdWords::v201309::AdScheduleTargetList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]' => 'Google::Ads::AdWords::v201309::BatchFailureResult',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::NegativeAdGroupCriterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingTransitionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/status' => 'Google::Ads::AdWords::v201309::CampaignStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201309::AdGroupExperimentBidMultipliers',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/reason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/scopingEntityId' => 'Google::Ads::AdWords::v201309::EntityId',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules' => 'Google::Ads::AdWords::v201309::FeedItemSchedule',
               'getResponse' => 'Google::Ads::AdWords::v201309::MutateJobService::getResponse',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignTargetOperation]/operand' => 'Google::Ads::AdWords::v201309::TargetList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[SimpleMutateJob]/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/PlaceHolder' => 'Google::Ads::AdWords::v201309::PlaceHolder',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride' => 'Google::Ads::AdWords::v201309::AdExtensionOverride',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterionExperimentData',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/bidModifierSource' => 'Google::Ads::AdWords::v201309::BidModifierSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/feedItemId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResponse/rval/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/attributeValues/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]' => 'Google::Ads::AdWords::v201309::ImageError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]' => 'Google::Ads::AdWords::v201309::FeedItemError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignError]' => 'Google::Ads::AdWords::v201309::CampaignError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]' => 'Google::Ads::AdWords::v201309::RejectedError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'Fault/detail/ApiExceptionFault/errors[CampaignAdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors' => 'Google::Ads::AdWords::v201309::FeedItemAttributeError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem' => 'Google::Ads::AdWords::v201309::FeedItem',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]' => 'Google::Ads::AdWords::v201309::AdGroupServiceError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResponse/rval[BulkMutateJob]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignOperation]/operand/budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[CampaignAdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201309::UserStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/reason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]' => 'Google::Ads::AdWords::v201309::CampaignError',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Media/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/history[BulkMutateJobEvent]/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/history/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'getResultResponse/rval/SimpleMutateResult/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ValidationStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval' => 'Google::Ads::AdWords::v201309::JobResult',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignOperation]/operand/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]' => 'Google::Ads::AdWords::v201309::AdGroupServiceError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResponse/rval[BulkMutateJob]/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/devicePreference/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201309::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::NegativeAdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201309::QualityInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterionExperimentData',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]' => 'Google::Ads::AdWords::v201309::QuotaError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/scheduling' => 'Google::Ads::AdWords::v201309::FeedItemScheduling',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[SimpleMutateJob]/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/integerValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/history' => 'Google::Ads::AdWords::v201309::JobEvent',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/reason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]' => 'Google::Ads::AdWords::v201309::FeedItemOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/startTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[BudgetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]' => 'Google::Ads::AdWords::v201309::MediaError',
               'getResponse/rval/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/approvalStatus' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::ApprovalStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/devicePreference' => 'Google::Ads::AdWords::v201309::FeedItemDevicePreference',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/attributeValues/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]' => 'Google::Ads::AdWords::v201309::BatchFailureResult',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[FeedItemOperation]/operand/validationDetails/approvalStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job' => 'Google::Ads::AdWords::v201309::Job',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/attributeValues/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[SimpleMutateJob]/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]' => 'Google::Ads::AdWords::v201309::BiddingErrors',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause' => 'Google::Ads::AdWords::v201309::ApiException',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[SimpleMutateJob]/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignAdExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand' => 'Google::Ads::AdWords::v201309::Campaign',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/status' => 'Google::Ads::AdWords::v201309::AdGroup::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/servingStatus' => 'Google::Ads::AdWords::v201309::ServingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/devicePreference/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/devicePreference' => 'Google::Ads::AdWords::v201309::FeedItemDevicePreference',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/targets/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/status' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/history' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]' => 'Google::Ads::AdWords::v201309::JobError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]' => 'Google::Ads::AdWords::v201309::BiddingErrors',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]' => 'Google::Ads::AdWords::v201309::JobError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]' => 'Google::Ads::AdWords::v201309::AdGroupBidModifierOperation',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]' => 'Google::Ads::AdWords::v201309::AdScheduleTargetList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroup',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[TargetError]' => 'Google::Ads::AdWords::v201309::TargetError',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[LostResult]' => 'Google::Ads::AdWords::v201309::LostResult',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResultResponse/rval/SimpleMutateResult/results/Ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]' => 'Google::Ads::AdWords::v201309::BiddingError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/approvalStatus' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/reason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[SimpleMutateJob]/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201309::TimeUnit',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/numRequestParts' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201309::AdServingOptimizationStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/bidModifierSource' => 'Google::Ads::AdWords::v201309::BidModifierSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[LostResult]' => 'Google::Ads::AdWords::v201309::LostResult',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'Fault/detail/ApiExceptionFault/errors[AdError]' => 'Google::Ads::AdWords::v201309::AdError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/reason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]' => 'Google::Ads::AdWords::v201309::QuotaError',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/attributeValues' => 'Google::Ads::AdWords::v201309::FeedItemAttributeValue',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResult/selector/JobSelector.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'getResultResponse/rval/SimpleMutateResult/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/approvalStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[SimpleMutateJob]/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/devicePreference/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201309::EntityAccessDenied',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors/validationErrorCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/history/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector[BulkMutateJobSelector]/jobIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[UnprocessedResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPMAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/integerValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/scheduling/feedItemSchedules/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand' => 'Google::Ads::AdWords::v201309::Campaign',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/bidModifierSource' => 'Google::Ads::AdWords::v201309::BidModifierSource',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo' => 'Google::Ads::AdWords::v201309::OverrideInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/feedMappingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]' => 'Google::Ads::AdWords::v201309::BiddingErrors',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/contentBidCriterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201309::EntityAccessDenied',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/errors[SettingError]' => 'Google::Ads::AdWords::v201309::SettingError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[BudgetOperation]/operand' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ValidationStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[SimpleMutateJob]/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[BudgetOperation]/operand/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/devicePreference' => 'Google::Ads::AdWords::v201309::FeedItemDevicePreference',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/approvalStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationErrors/validationErrorCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/reason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupAdCountLimitExceeded',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BulkMutateJobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/reason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations' => 'Google::Ads::AdWords::v201309::Operation',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/approvalStatus' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations[CampaignOperation]/operand/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]' => 'Google::Ads::AdWords::v201309::CampaignOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingError]' => 'Google::Ads::AdWords::v201309::BiddingError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201309::SystemServingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[LostResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/startTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]' => 'Google::Ads::AdWords::v201309::CampaignCriterionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/errors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupAdCountLimitExceeded',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/status' => 'Google::Ads::AdWords::v201309::AdGroup::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]' => 'Google::Ads::AdWords::v201309::BiddingErrors',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'get/selector/includeStats' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo::RadiusUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/scheduling/feedItemSchedules/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]' => 'Google::Ads::AdWords::v201309::OperatorError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget' => 'Google::Ads::AdWords::v201309::Budget',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]' => 'Google::Ads::AdWords::v201309::ImageError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[CampaignAdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[LostResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/scopingEntityId' => 'Google::Ads::AdWords::v201309::EntityId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList' => 'Google::Ads::AdWords::v201309::TargetList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::NegativeAdGroupCriterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201309::QualityInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]' => 'Google::Ads::AdWords::v201309::AdGroupServiceError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/endTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201309::UserStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupAdOperation]/operand/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/targets/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]' => 'Google::Ads::AdWords::v201309::CampaignTargetOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterionExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[JobError]' => 'Google::Ads::AdWords::v201309::JobError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/reason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[SimpleMutateJob]/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'mutate/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[FeedItemOperation]' => 'Google::Ads::AdWords::v201309::FeedItemOperation',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/validationDetails/validationStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ValidationStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/approvalStatus' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201309::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/bidModifierSource' => 'Google::Ads::AdWords::v201309::BidModifierSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionOperation',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[LostResult]' => 'Google::Ads::AdWords::v201309::LostResult',
               'getResponse/rval[SimpleMutateJob]/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion' => 'Google::Ads::AdWords::v201309::AdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/status' => 'Google::Ads::AdWords::v201309::AdGroup::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap' => 'Google::Ads::AdWords::v201309::FrequencyCap',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[UnprocessedResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutateResponse/rval/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap' => 'Google::Ads::AdWords::v201309::FrequencyCap',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/errors[AdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[FeedItemOperation]/operand/validationDetails/feedMappingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[FeedItemError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion' => 'Google::Ads::AdWords::v201309::AdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[SettingError]/reason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded::CriteriaLimitType',
               'getResponse/rval/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]' => 'Google::Ads::AdWords::v201309::JobError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'mutateResponse/rval/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/reason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/level' => 'Google::Ads::AdWords::v201309::Level',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/level' => 'Google::Ads::AdWords::v201309::Level',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/validationDetails/feedMappingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201309::AdServingOptimizationStatus',
               'Fault/detail/ApiExceptionFault/errors[AdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams' => 'Google::Ads::AdWords::v201309::OperationStream',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/attributeValues/integerValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[BulkMutateJobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]' => 'Google::Ads::AdWords::v201309::CampaignError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[FeedItemError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/scopingEntityId/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList' => 'Google::Ads::AdWords::v201309::TargetList',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201309::UserStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]' => 'Google::Ads::AdWords::v201309::AdGroupOperation',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/scheduling/feedItemSchedules/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]' => 'Google::Ads::AdWords::v201309::AdGroupAdError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[BudgetOperation]/operand/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result' => 'Google::Ads::AdWords::v201309::BulkMutateResult',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignError]/reason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[BulkMutateJobError]/reason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/reason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ValidationStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[SimpleMutateJob]/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[FeedItemError]/reason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::NegativeAdGroupCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap/level' => 'Google::Ads::AdWords::v201309::Level',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/policy/prerequisiteJobIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/bidModifierSource' => 'Google::Ads::AdWords::v201309::BidModifierSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]' => 'Google::Ads::AdWords::v201309::CampaignError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/status' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::Status',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult' => 'Google::Ads::AdWords::v201309::BulkMutateResult',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201309::SimpleMutateJob',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request' => 'Google::Ads::AdWords::v201309::BulkMutateRequest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPMAdGroupExperimentBidMultipliers',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignAdExtensionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignAdExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/reason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationErrors/feedAttributeIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign' => 'Google::Ads::AdWords::v201309::Campaign',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap/level' => 'Google::Ads::AdWords::v201309::Level',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]' => 'Google::Ads::AdWords::v201309::CampaignOperation',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operand/attributeValues/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201309::EntityAccessDenied',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupBidModifier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'get/selector[BulkMutateJobSelector]/includeStats' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/status' => 'Google::Ads::AdWords::v201309::FeedItem::Status',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/reason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201309::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/feedMappingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutateResponse/rval/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getResponse/rval[SimpleMutateJob]/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/errors[JobError]/reason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/contentBidCriterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'mutate/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[SimpleMutateJob]/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded::CriteriaLimitType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]' => 'Google::Ads::AdWords::v201309::QuotaError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupExperimentBidMultipliers',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResponse/rval[BulkMutateJob]/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo::RadiusUnits',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand' => 'Google::Ads::AdWords::v201309::TargetList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201309::SystemServingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/reason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults' => 'Google::Ads::AdWords::v201309::OperationResult',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]' => 'Google::Ads::AdWords::v201309::BulkMutateJobError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/reason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationErrors' => 'Google::Ads::AdWords::v201309::FeedItemAttributeError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/feedItemId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/servingStatus' => 'Google::Ads::AdWords::v201309::ServingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue' => 'Google::Ads::AdWords::v201309::Operand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201309::AdServingOptimizationStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutateResponse/rval/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[LostResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[FeedItemError]/reason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]' => 'Google::Ads::AdWords::v201309::CampaignCriterionOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]' => 'Google::Ads::AdWords::v201309::CampaignCriterionOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo::RadiusUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[SimpleMutateJob]/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/errors[BulkMutateJobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo' => 'Google::Ads::AdWords::v201309::OverrideInfo',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults' => 'Google::Ads::AdWords::v201309::OperationStreamResult',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201309::RejectedError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]/trackingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling' => 'Google::Ads::AdWords::v201309::FeedItemScheduling',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CampaignErrorReason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]' => 'Google::Ads::AdWords::v201309::SettingError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[UnprocessedResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/feedItemId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/reason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::NegativeAdGroupCriterion',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/SelectorErrorReason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/reason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupServiceError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]' => 'Google::Ads::AdWords::v201309::CampaignOperation',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]' => 'Google::Ads::AdWords::v201309::TargetError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/feedItemId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResponse/rval[SimpleMutateJob]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[FeedItemOperation]/operand/validationDetails/validationErrors/feedAttributeIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]' => 'Google::Ads::AdWords::v201309::FeedItemError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request' => 'Google::Ads::AdWords::v201309::BulkMutateRequest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/reason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/frequencyCap/level' => 'Google::Ads::AdWords::v201309::Level',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[SimpleMutateJob]/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201309::TimeUnit',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[SimpleMutateJob]' => 'Google::Ads::AdWords::v201309::SimpleMutateJob',
               'getResponse/rval[SimpleMutateJob]/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[SimpleMutateJob]/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/AuthorizationErrorReason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride' => 'Google::Ads::AdWords::v201309::AdExtensionOverride',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/errors[JobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/ForwardCompatibilityErrorReason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors/validationErrorCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/reason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations' => 'Google::Ads::AdWords::v201309::Operation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/bidModifierSource' => 'Google::Ads::AdWords::v201309::BidModifierSource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[FeedItemOperation]/operand' => 'Google::Ads::AdWords::v201309::FeedItem',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/reason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'mutate/operations[BudgetOperation]' => 'Google::Ads::AdWords::v201309::BudgetOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'mutate/operations[AdGroupOperation]' => 'Google::Ads::AdWords::v201309::AdGroupOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension' => 'Google::Ads::AdWords::v201309::CampaignAdExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/history' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201309::AdServingOptimizationStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]' => 'Google::Ads::AdWords::v201309::AdGroupBidModifierOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling' => 'Google::Ads::AdWords::v201309::FeedItemScheduling',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/DateErrorReason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/bidModifierSource' => 'Google::Ads::AdWords::v201309::BidModifierSource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job' => 'Google::Ads::AdWords::v201309::Job',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]' => 'Google::Ads::AdWords::v201309::AdError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier' => 'Google::Ads::AdWords::v201309::AdGroupBidModifier',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[SettingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutateResponse/rval/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionOperation',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request' => 'Google::Ads::AdWords::v201309::BulkMutateRequest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'mutateResponse/rval/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults' => 'Google::Ads::AdWords::v201309::OperationStreamResult',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[MediaError]' => 'Google::Ads::AdWords::v201309::MediaError',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdGroupAdErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201309::RealTimeBiddingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign' => 'Google::Ads::AdWords::v201309::Campaign',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]' => 'Google::Ads::AdWords::v201309::BatchFailureResult',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules' => 'Google::Ads::AdWords::v201309::FeedItemSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded::CriteriaLimitType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/JobErrorReason' => 'Google::Ads::AdWords::v201309::JobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Target[AdScheduleTarget]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[UnprocessedResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause' => 'Google::Ads::AdWords::v201309::ApiException',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[BulkMutateJobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/targets/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/reason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/reason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/reason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/policy' => 'Google::Ads::AdWords::v201309::BulkMutateJobPolicy',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'Fault/detail/ApiExceptionFault/errors[CampaignAdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/amount' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[ImageError]/reason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules' => 'Google::Ads::AdWords::v201309::FeedItemSchedule',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result' => 'Google::Ads::AdWords::v201309::BulkMutateResult',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/NotEmptyErrorReason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/history/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/billingSummary' => 'Google::Ads::AdWords::v201309::BillingSummary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]' => 'Google::Ads::AdWords::v201309::CampaignCriterionError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutateResponse/rval/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201309::OAuthInfo',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]/targets/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector[BulkMutateJobSelector]/JobSelector.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[BudgetError]' => 'Google::Ads::AdWords::v201309::BudgetError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201309::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupServiceError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutateResponse/rval/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'mutateResponse/rval/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'mutate/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList[AdScheduleTargetList]' => 'Google::Ads::AdWords::v201309::AdScheduleTargetList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201309::EntityAccessDenied',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults' => 'Google::Ads::AdWords::v201309::OperationResult',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/MediaErrorReason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/details/targetAll' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]' => 'Google::Ads::AdWords::v201309::AdGroupBidModifierOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/BiddingErrorReason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/CriterionErrorReason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[AdGroupOperation]/operand/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupAdOperation]/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'mutate/operations[BudgetOperation]/operand/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroup::Status',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResultResponse/rval/SimpleMutateResult' => 'Google::Ads::AdWords::v201309::SimpleMutateResult',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults' => 'Google::Ads::AdWords::v201309::OperationStreamResult',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/reason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules' => 'Google::Ads::AdWords::v201309::FeedItemSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/reason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[TargetingSetting]/details' => 'Google::Ads::AdWords::v201309::TargetingSettingDetail',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/scheduling/feedItemSchedules/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'mutateResponse/rval/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/SimpleMutateResult/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector[BulkMutateJobSelector]' => 'Google::Ads::AdWords::v201309::BulkMutateJobSelector',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::CampaignCriterionLimitExceeded::CriteriaLimitType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier' => 'Google::Ads::AdWords::v201309::AdGroupBidModifier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]' => 'Google::Ads::AdWords::v201309::QuotaError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResponse/rval[SimpleMutateJob]/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'Fault/detail/ApiExceptionFault/errors[FeedItemError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'mutate/operations[AdGroupAdOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'mutateResponse/rval/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/errors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201309::BiddableAdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/errors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/integerValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]' => 'Google::Ads::AdWords::v201309::CampaignCriterionOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/policy' => 'Google::Ads::AdWords::v201309::BulkMutateJobPolicy',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target' => 'Google::Ads::AdWords::v201309::Target',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/QuotaErrorReason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdExtensionOverride/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand' => 'Google::Ads::AdWords::v201309::FeedItem',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201309::AdGroupExperimentBidMultipliers',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaError]/reason' => 'Google::Ads::AdWords::v201309::QuotaError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/period' => 'Google::Ads::AdWords::v201309::Budget::BudgetPeriod',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[JobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/feedMappingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResult' => 'Google::Ads::AdWords::v201309::MutateJobService::getResult',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/operand/scheduling/feedItemSchedules/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[BatchFailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/reason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/DistinctErrorReason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignOperation]/operand/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/AdGroupCriterionErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[SimpleMutateJob]/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]' => 'Google::Ads::AdWords::v201309::AdScheduleTargetList',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension' => 'Google::Ads::AdWords::v201309::CampaignAdExtension',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/TargetErrorReason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/AdxErrorReason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]' => 'Google::Ads::AdWords::v201309::AdGroupAdError',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201309::AdGroupCriterionExperimentBidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/OperationResult.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]' => 'Google::Ads::AdWords::v201309::SimpleMutateJob',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo::RadiusUnits',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/reason' => 'Google::Ads::AdWords::v201309::CampaignError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/budget/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::EnhancedCpcBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupBidModifier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]' => 'Google::Ads::AdWords::v201309::AdExtensionError',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/TargetList' => 'Google::Ads::AdWords::v201309::TargetList',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/OperationAccessDeniedReason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]' => 'Google::Ads::AdWords::v201309::AdGroupBidModifierOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/PlaceHolder' => 'Google::Ads::AdWords::v201309::PlaceHolder',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/history' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]' => 'Google::Ads::AdWords::v201309::CampaignError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201309::KeywordMatchSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[SimpleMutateJob]/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/billingSummary/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]' => 'Google::Ads::AdWords::v201309::MediaError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/contentBidCriterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201309::DomainInfoExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget' => 'Google::Ads::AdWords::v201309::Budget',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[BulkMutateJobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TrackingSetting]' => 'Google::Ads::AdWords::v201309::TrackingSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/validationErrors/feedAttributeIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand' => 'Google::Ads::AdWords::v201309::FeedItem',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201309::QualityInfo',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ClientTermsErrorReason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/failureReason/AuthenticationErrorReason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]' => 'Google::Ads::AdWords::v201309::MobileDevice',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Media' => 'Google::Ads::AdWords::v201309::Media',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201309::MobileExtension',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/InternalApiErrorReason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand' => 'Google::Ads::AdWords::v201309::Budget',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/attributeValues/integerValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignAdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/failureReason/FeedItemErrorReason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[FeedItemError]/reason' => 'Google::Ads::AdWords::v201309::FeedItemError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/status' => 'Google::Ads::AdWords::v201309::Budget::BudgetStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target' => 'Google::Ads::AdWords::v201309::Target',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201309::AgeRange',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job' => 'Google::Ads::AdWords::v201309::Job',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/EntityCountLimitExceededReason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[SimpleMutateJob]/history[BulkMutateJobEvent]' => 'Google::Ads::AdWords::v201309::BulkMutateJobEvent',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]/operationIndexInBatch' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/deviceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/stats' => 'Google::Ads::AdWords::v201309::JobStats',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201309::LocationExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/BudgetErrorReason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]' => 'Google::Ads::AdWords::v201309::BiddingTransitionError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpcBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion' => 'Google::Ads::AdWords::v201309::AdGroupCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/stats[BulkMutateJobStats]/numUnprocessedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'mutateResponse/rval/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[RejectedError]' => 'Google::Ads::AdWords::v201309::RejectedError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/status' => 'Google::Ads::AdWords::v201309::CampaignStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]' => 'Google::Ads::AdWords::v201309::BiddingError',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/approvalStatus' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[ExplorerAutoOptimizerSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]' => 'Google::Ads::AdWords::v201309::NegativeCampaignCriterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/BulkMutateResult/partIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201309::ManualCpmBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension' => 'Google::Ads::AdWords::v201309::AdExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/PagingErrorReason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/referenceCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetSpendBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201309::TimeUnit',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201309::CpmBid',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/PolicyViolationErrorReason' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutateResponse/rval/stats[BulkMutateJobStats]/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings' => 'Google::Ads::AdWords::v201309::Setting',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingTransitionError]/reason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignAdExtensionOperation]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]' => 'Google::Ads::AdWords::v201309::AdError',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201309::BiddingScheme',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/servingStatus' => 'Google::Ads::AdWords::v201309::ServingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion' => 'Google::Ads::AdWords::v201309::Criterion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]' => 'Google::Ads::AdWords::v201309::SimpleMutateJob',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/SettingErrorReason' => 'Google::Ads::AdWords::v201309::SettingError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201309::BiddingStrategySource',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target[AdScheduleTarget]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AdError]' => 'Google::Ads::AdWords::v201309::AdError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]' => 'Google::Ads::AdWords::v201309::Proximity',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/partIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201309::CpcBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'Fault/detail/ApiExceptionFault/errors[BulkMutateJobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201309::BiddingStrategyType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::Status',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/isExplicitlyShared' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]/operand/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]' => 'Google::Ads::AdWords::v201309::ImageError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/status' => 'Google::Ads::AdWords::v201309::AdExtensionOverride::Status',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupOperation]/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats/progressPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]' => 'Google::Ads::AdWords::v201309::TargetError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/stats[BulkMutateJobStats]/processingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201309::QualityInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'mutate/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]' => 'Google::Ads::AdWords::v201309::BulkMutateJobError',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201309::LocationSyncExtension',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/Target.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/RequiredErrorReason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/AdGroupServiceErrorReason' => 'Google::Ads::AdWords::v201309::AdGroupServiceError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileDevice]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/CampaignCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BiddingTransitionErrorReason' => 'Google::Ads::AdWords::v201309::BiddingTransitionError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats[BulkMutateJobStats]/pendingTimeMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BiddingErrorsReason' => 'Google::Ads::AdWords::v201309::BiddingErrors::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand' => 'Google::Ads::AdWords::v201309::AdExtensionOverride',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/status' => 'Google::Ads::AdWords::v201309::BasicJobStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/StatsQueryErrorReason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/partIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/settings[ExplorerAutoOptimizerSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RejectedErrorReason' => 'Google::Ads::AdWords::v201309::RejectedError::Reason',
               'getResponse/rval[SimpleMutateJob]/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionOperation',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201309::AdGroupExperimentBidMultipliers',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[UnprocessedResult]' => 'Google::Ads::AdWords::v201309::UnprocessedResult',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget' => 'Google::Ads::AdWords::v201309::Budget',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility::RejectionReason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride' => 'Google::Ads::AdWords::v201309::AdExtensionOverride',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BulkMutateJobError]' => 'Google::Ads::AdWords::v201309::BulkMutateJobError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval/stats[BulkMutateJobStats]/numOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdError]/reason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/NotWhitelistedErrorReason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval[SimpleMutateJob]/failureReason/RequestErrorReason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RegionCodeErrorReason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignOperation]/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::PricingMode',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/failureReason' => 'Google::Ads::AdWords::v201309::ApiErrorReason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse' => 'Google::Ads::AdWords::v201309::MutateJobService::getResultResponse',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[TargetingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupExperimentData',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting::NegativeGeoTargetType',
               'getResponse/rval[SimpleMutateJob]/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/failureReason/NullErrorReason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/CampaignCriterionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignCriterionError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]' => 'Google::Ads::AdWords::v201309::FailureResult',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201309::AdServingOptimizationStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201309::SitelinksExtension',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/validationErrors/validationErrorCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]' => 'Google::Ads::AdWords::v201309::AdScheduleTargetList',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[MediaError]/reason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/validationDetails/feedMappingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201309::LocationExtension::Source',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RateExceededErrorReason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201309::BidSource',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/TargetList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201309::GeoTargetTypeSetting',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo::RadiusUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/deviceType' => 'Google::Ads::AdWords::v201309::MobileDevice::DeviceType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/startMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'getResponse/rval/failureReason/AdErrorReason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileDevice]/manufacturerName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/BulkMutateJobErrorReason' => 'Google::Ads::AdWords::v201309::BulkMutateJobError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignAdExtensionOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/ImageErrorReason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMajorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignAdExtensionError]/reason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/SizeLimitErrorReason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/attributeValues/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[FeedItemOperation]/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileDevice]/operatingSystemName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201309::Bids',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/AdExtensionOverrideErrorReason' => 'Google::Ads::AdWords::v201309::AdExtensionOverrideError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]/numFailedOperations' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/OperatorErrorReason' => 'Google::Ads::AdWords::v201309::OperatorError::Reason',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Media[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/NewEntityCreationErrorReason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]' => 'Google::Ads::AdWords::v201309::BulkMutateJob',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/failureReason/ReadOnlyErrorReason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]' => 'Google::Ads::AdWords::v201309::ReturnValueResult',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/history/dateTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201309::InAppLinkExtension::AppStore',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/endTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201309::InAppLinkExtension',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/dayOfWeek' => 'Google::Ads::AdWords::v201309::DayOfWeek',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/StringLengthErrorReason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]' => 'Google::Ads::AdWords::v201309::SettingError',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201309::QualityInfo',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/startHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201309::BudgetOptimizerBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[ExplorerAutoOptimizerSetting]' => 'Google::Ads::AdWords::v201309::ExplorerAutoOptimizerSetting',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201309::CpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Proximity]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/DatabaseErrorReason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Proximity]/radiusDistanceUnits' => 'Google::Ads::AdWords::v201309::Proximity::DistanceUnits',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Campaign/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Media/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]' => 'Google::Ads::AdWords::v201309::Carrier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[SimpleMutateJob]/Job.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Target' => 'Google::Ads::AdWords::v201309::Target',
               'getResultResponse/rval/SimpleMutateResult/errors[CampaignCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Budget/deliveryMethod' => 'Google::Ads::AdWords::v201309::Budget::BudgetDeliveryMethod',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupAdCountLimitExceeded',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/settings[TargetingSetting]/details/criterionTypeGroup' => 'Google::Ads::AdWords::v201309::CriterionTypeGroup',
               'getResultResponse/rval/SimpleMutateResult/errors[AdGroupAdError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201309::ConversionOptimizerBiddingScheme::BidType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/FeedItem/devicePreference' => 'Google::Ads::AdWords::v201309::FeedItemDevicePreference',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201309::EntityAccessDenied',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResult/selector[BulkMutateJobSelector]/includeStats' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::PercentCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Proximity]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]' => 'Google::Ads::AdWords::v201309::RejectedError',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[BatchFailureResult]/operationIndexInBatch' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201309::PercentCpaBid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Proximity]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion' => 'Google::Ads::AdWords::v201309::CampaignCriterion',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]/contentLabelType' => 'Google::Ads::AdWords::v201309::ContentLabelType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/failureReason/BetaErrorReason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/policy/prerequisiteJobIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[AdSchedule]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupAdOperation]/operand/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/stats[BulkMutateJobStats]' => 'Google::Ads::AdWords::v201309::BulkMutateJobStats',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201309::PageOnePromotedBiddingScheme::StrategyGoal',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/CampaignAdExtensionErrorReason' => 'Google::Ads::AdWords::v201309::CampaignAdExtensionError::Reason',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201309::BiddingStrategyConfiguration',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/budget/budgetId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/partIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/history[BulkMutateJobEvent]/JobEvent.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[MobileDevice]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/status' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::Status',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[FeedItemOperation]/operand/devicePreference' => 'Google::Ads::AdWords::v201309::FeedItemDevicePreference',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/billingSummary/numUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/IdErrorReason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignTargetOperation]/operand[AdScheduleTargetList]/targets/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job/failureReason/QuotaCheckErrorReason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::CampaignAdExtension::ApprovalStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterionUse' => 'Google::Ads::AdWords::v201309::CriterionUse',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201309::AgeRange::AgeRangeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ImageError]/reason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[SimpleMutateJob]/failureReason/EntityNotFoundReason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations[AdGroupAdOperation]/operand/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[ContentLabel]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets' => 'Google::Ads::AdWords::v201309::AdScheduleTarget',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201309::SystemServingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupServiceError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[AdGroupAdCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand/validationDetails/approvalStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ApprovalStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[AdSchedule]/endMinute' => 'Google::Ads::AdWords::v201309::MinuteOfHour',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RejectedError]' => 'Google::Ads::AdWords::v201309::RejectedError',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/isNegative' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[AdGroupAdOperation]/operand/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[ContentLabel]' => 'Google::Ads::AdWords::v201309::ContentLabel',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/QueryErrorReason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[OperatingSystemVersion]/operatorType' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion::OperatorType',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[AdSchedule]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupAdOperation]/operand/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo::RadiusUnits',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdExtensionOverride/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201309::LocationOverrideInfo',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[FeedItemOperation]/operand' => 'Google::Ads::AdWords::v201309::FeedItem',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Media[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[JobError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations[AdGroupOperation]/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[ContentLabel]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[SimpleMutateJob]/failureReason/RangeErrorReason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/CampaignAdExtension/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201309::Sitelink',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201309::ConversionOptimizerEligibility::RejectionReason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[MobileDevice]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'mutate/operations[AdGroupOperation]/operand/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[CampaignCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/geoPoint' => 'Google::Ads::AdWords::v201309::GeoPoint',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[AdSchedule]/endHour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[AdSchedule]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Proximity]/radiusInUnits' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[AdSchedule]' => 'Google::Ads::AdWords::v201309::AdSchedule',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/settings[TargetingSetting]' => 'Google::Ads::AdWords::v201309::TargetingSetting',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'mutate/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Carrier]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[SettingError]' => 'Google::Ads::AdWords::v201309::SettingError',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]' => 'Google::Ads::AdWords::v201309::OperatingSystemVersion',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201309::Gender::GenderType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Campaign/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Proximity]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[BudgetOperation]' => 'Google::Ads::AdWords::v201309::BudgetOperation',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/TargetList[AdScheduleTargetList]/targets/bidMultiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/validationDetails/approvalStatus' => 'Google::Ads::AdWords::v201309::FeedItemValidationDetail::ApprovalStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroup/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[SimpleMutateJob]/failureReason/EntityAccessDeniedReason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Carrier]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdExtensionOverrideOperation]/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/stats/JobStats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignCriterion[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[BiddableAdGroupCriterion]/criterion[OperatingSystemVersion]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignOperation]/operand/frequencyCap/level' => 'Google::Ads::AdWords::v201309::Level',
               'getResultResponse/rval/SimpleMutateResult/errors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Carrier]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations[CampaignCriterionOperation]/operand/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[FailureResult]/cause/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion[NegativeAdGroupCriterion]/criterion[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201309::Bid',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[LostResult]' => 'Google::Ads::AdWords::v201309::LostResult',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/SimpleMutateResult/results/FeedItem/devicePreference' => 'Google::Ads::AdWords::v201309::FeedItemDevicePreference',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupCriterion/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/CampaignAdExtension/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Proximity]/address' => 'Google::Ads::AdWords::v201309::Address',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[CampaignAdExtensionOperation]/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201309::Gender',
               'mutate/operations[CampaignCriterionOperation]/operand[NegativeCampaignCriterion]/criterion[OperatingSystemVersion]/osMinorVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations[CampaignOperation]/operand/settings[TrackingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupBidModifierOperation]/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201309::BidMultiplier',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupOperation]/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201309::ManualCPMAdGroupExperimentBidMultipliers',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroupAd/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/SimpleMutateResult/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupAd/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupCriterion[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201309::TargetCpaBiddingScheme',
               'getResultResponse/rval/SimpleMutateResult/results/AdGroup/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201309::Money',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/result/operationStreamResults/operationResults[ReturnValueResult]/returnValue/AdGroupBidModifier/criterion[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResultResponse/rval/SimpleMutateResult/results/Job[BulkMutateJob]/request/operationStreams/operations[AdGroupAdOperation]/operand/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/request/operationStreams/operations[AdGroupCriterionOperation]/operand[BiddableAdGroupCriterion]/criterion[Proximity]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResultResponse/rval/BulkMutateResult/operationStreamResults/operationResults[ReturnValueResult]/returnValue/Job[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval[BulkMutateJob]/result/operationStreamResults/operationResults[FailureResult]/cause/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::EntityAccessDenied::Reason'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201309::TypeMaps::MutateJobService - typemap for MutateJobService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

