
package Google::Ads::AdWords::v201402::TypeMaps::AdGroupCriterionService;
use strict;
use warnings;

our $typemap_1 = {
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingError]' => 'Google::Ads::AdWords::v201402::BiddingError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/targetRoas' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201402::Predicate',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201402::PageOnePromotedBiddingScheme',
               'mutateResponse/rval/partialFailureErrors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ExperimentError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201402::RateExceededError::Reason',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201402::PercentCpaBid',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'getResponse/rval/entries/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201402::BiddingStrategyConfiguration',
               'mutate/operations/exemptionRequests' => 'Google::Ads::AdWords::v201402::ExemptionRequest',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201402::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201402::ManualCpmBiddingScheme',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'mutateResponse/rval/partialFailureErrors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201402::Bid',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201402::DateError::Reason',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/reason' => 'Google::Ads::AdWords::v201402::RequiredError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201402::BiddingStrategyConfiguration',
               'queryResponse/rval/entries/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201402::BidMultiplier',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]' => 'Google::Ads::AdWords::v201402::SizeLimitError',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'queryResponse/rval/entries/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201402::NegativeAdGroupCriterion',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/reason' => 'Google::Ads::AdWords::v201402::DistinctError::Reason',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval' => 'Google::Ads::AdWords::v201402::AdGroupCriterionPage',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201402::ClientTermsError',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201402::EntityAccessDenied',
               'mutate/operations/operand/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/reason' => 'Google::Ads::AdWords::v201402::QueryError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'getResponse/rval/entries/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201402::RejectedError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201402::CpcBid',
               'getResponse/rval/entries/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'mutate/operations/operand/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'mutate/operations/operand[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201402::UserStatus',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201402::Operator',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'mutateResponse/rval/partialFailureErrors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]' => 'Google::Ads::AdWords::v201402::NotEmptyError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]' => 'Google::Ads::AdWords::v201402::RequestError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201402::ForwardCompatibilityError::Reason',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]' => 'Google::Ads::AdWords::v201402::AuthorizationError',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'mutate/operations/operand/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]' => 'Google::Ads::AdWords::v201402::NullError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/reason' => 'Google::Ads::AdWords::v201402::SelectorError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201402::BiddableAdGroupCriterionExperimentData',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201402::ReadOnlyError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]' => 'Google::Ads::AdWords::v201402::StatsQueryError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetSpendBiddingScheme',
               'mutateResponse/rval/partialFailureErrors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201402::Bid',
               'mutateResponse/rval/value/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'queryResponse/rval/entries/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201402::PageOnePromotedBiddingScheme::StrategyGoal',
               'mutate/operations/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'queryResponse/rval/entries/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201402::ExperimentDataStatus',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201402::AuthenticationError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme::PricingMode',
               'getResponse/rval/entries/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201402::BudgetOptimizerBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[AdxError]' => 'Google::Ads::AdWords::v201402::AdxError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetCpaBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'queryResponse/rval/entries/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201402::NewEntityCreationError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[IdError]' => 'Google::Ads::AdWords::v201402::IdError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'get' => 'Google::Ads::AdWords::v201402::AdGroupCriterionService::get',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme::BidType',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201402::QuotaCheckError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'getResponse/rval/entries/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'queryResponse/rval/entries/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'mutateResponse/rval/partialFailureErrors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'mutate/operations/operand/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetRoasBiddingScheme',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201402::Bid',
               'getResponse/rval/entries/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201402::BiddingScheme',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'queryResponse/rval/entries/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201402::DistinctError::Reason',
               'mutate/operations/operand/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201402::BidMultiplier',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme::BidType',
               'Fault/detail/ApiExceptionFault/errors[PagingError]' => 'Google::Ads::AdWords::v201402::PagingError',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme::PricingMode',
               'mutate/operations/operand/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'getResponse/rval/entries/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval' => 'Google::Ads::AdWords::v201402::AdGroupCriterionPage',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201402::CpmBid',
               'getResponse/rval/entries/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201402::ExperimentDeltaStatus',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'queryResponse/rval/entries/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PagingError]' => 'Google::Ads::AdWords::v201402::PagingError',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201402::RangeError',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201402::BiddableAdGroupCriterionExperimentData',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201402::EntityCountLimitExceeded',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201402::PolicyViolationKey',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ExperimentError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'queryResponse/rval/entries/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate' => 'Google::Ads::AdWords::v201402::AdGroupCriterionService::mutate',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'queryResponse/rval/entries/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201402::ManualCpmBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201402::BiddingError::Reason',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201402::AdGroupCriterionError::Reason',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201402::SizeLimitError::Reason',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201402::ExperimentDataStatus',
               'getResponse/rval/entries/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201402::Bid',
               'mutateResponse/rval/partialFailureErrors[SelectorError]' => 'Google::Ads::AdWords::v201402::SelectorError',
               'getResponse/rval/entries/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201402::EntityAccessDenied::Reason',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'getResponse/rval/entries[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201402::NegativeAdGroupCriterion',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201402::AdGroupCriterionReturnValue',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201402::PolicyViolationError::Part',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201402::NewEntityCreationError::Reason',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201402::Selector',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201402::PagingError::Reason',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201402::SelectorError',
               'mutateResponse/rval/value/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'mutate/operations/operand[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201402::EntityNotFound::Reason',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'mutateResponse/rval/partialFailureErrors[ExperimentError]/reason' => 'Google::Ads::AdWords::v201402::ExperimentError::Reason',
               'mutate/operations/operand/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201402::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme::BidType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201402::PolicyViolationKey',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201402::BiddableAdGroupCriterion',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201402::BiddableAdGroupCriterion',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201402::Bid',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201402::AdGroupCriterion',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201402::BiddingStrategyType',
               'getResponse/rval/entries/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201402::BidMultiplier',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]' => 'Google::Ads::AdWords::v201402::PolicyViolationError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201402::Bids',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'queryResponse/rval/entries/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/reason' => 'Google::Ads::AdWords::v201402::RejectedError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'queryResponse/rval/entries/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme::BidType',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'mutate/operations/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201402::ExperimentDataStatus',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'mutate/operations/operand/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201402::DateError',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/reason' => 'Google::Ads::AdWords::v201402::NullError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201402::MultiplierSource',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201402::Bid',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ExperimentError]' => 'Google::Ads::AdWords::v201402::ExperimentError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201402::StatsQueryError::Reason',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'mutate/operations/operand/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201402::BiddableAdGroupCriterion',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme',
               'getResponse/rval/entries/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'getResponse/rval/entries/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201402::PolicyViolationError::Part',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries' => 'Google::Ads::AdWords::v201402::AdGroupCriterion',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]' => 'Google::Ads::AdWords::v201402::RateExceededError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201402::SelectorError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'queryResponse/rval/entries/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201402::AuthorizationError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201402::QualityInfo',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ExperimentError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201402::BudgetOptimizerBiddingScheme',
               'mutate/operations/operand[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201402::CpcBid',
               'queryResponse/rval/entries/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201402::Bid',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/partialFailureErrors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201402::BiddingScheme',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/reason' => 'Google::Ads::AdWords::v201402::RangeError::Reason',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201402::ReadOnlyError::Reason',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/targetRoas' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]' => 'Google::Ads::AdWords::v201402::StringLengthError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201402::PageOnePromotedBiddingScheme::StrategyGoal',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201402::RequestError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'mutateResponse/rval/value/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201402::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'mutateResponse/rval/value/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201402::BiddingErrors::Reason',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201402::EntityCountLimitExceeded::Reason',
               'getResponse/rval/entries/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'mutateResponse/rval/value/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201402::StringLengthError::Reason',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201402::BiddingErrors::Reason',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse' => 'Google::Ads::AdWords::v201402::AdGroupCriterionService::mutateResponse',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ExperimentError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201402::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/topOfPageCpc' => 'Google::Ads::AdWords::v201402::Bid',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201402::DatabaseError::Reason',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201402::ManualCpcBiddingScheme',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'mutateResponse/rval/value/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]' => 'Google::Ads::AdWords::v201402::CriterionError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201402::ManualCpmBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/exemptionRequests/key' => 'Google::Ads::AdWords::v201402::PolicyViolationKey',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201402::BudgetOptimizerBiddingScheme',
               'mutateResponse/rval/value/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'mutateResponse/rval/value/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201402::Bid',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201402::EntityNotFound',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'mutate/operations/operand/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201402::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme',
               'mutate/operations/operand/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'getResponse/rval/entries/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]' => 'Google::Ads::AdWords::v201402::QuotaCheckError',
               'Fault/detail/ApiExceptionFault/errors[ExperimentError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'mutate/operations/operand/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201402::PolicyViolationKey',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'getResponse/rval/entries/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201402::OrderBy',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201402::CpcBid',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201402::RequiredError::Reason',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201402::Bids',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201402::AdxError::Reason',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201402::ReadOnlyError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201402::NullError::Reason',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201402::CriterionPolicyError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'mutateResponse/rval/partialFailureErrors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201402::PercentCpaBid',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201402::PageOnePromotedBiddingScheme',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201402::ManualCpcBiddingScheme',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ExperimentError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'queryResponse/rval/entries/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201402::PageOnePromotedBiddingScheme',
               'queryResponse/rval/entries/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201402::QualityInfo',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201402::BiddingStrategyType',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201402::RejectedError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201402::ClientTermsError::Reason',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201402::AdGroupCriterion',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations' => 'Google::Ads::AdWords::v201402::AdGroupCriterionOperation',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'queryResponse/rval/entries/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'mutateResponse/rval/partialFailureErrors' => 'Google::Ads::AdWords::v201402::ApiError',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'mutate/operations/operand[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetCpaBiddingScheme',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201402::StatsQueryError',
               'mutateResponse/rval/partialFailureErrors[RejectedError]' => 'Google::Ads::AdWords::v201402::RejectedError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201402::MultiplierSource',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201402::SystemServingStatus',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]' => 'Google::Ads::AdWords::v201402::ClientTermsError',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetSpendBiddingScheme',
               'mutateResponse/rval/value/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/value/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201402::Predicate::Operator',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201402::BiddingStrategyConfiguration',
               'queryResponse/rval/entries/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201402::CpmBid',
               'mutate/operations/operand/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201402::PercentCpaBiddingScheme',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/partialFailureErrors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'queryResponse/rval/entries/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201402::ApprovalStatus',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201402::EntityCountLimitExceeded',
               'getResponse/rval/entries/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201402::InternalApiError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201402::PageOnePromotedBiddingScheme',
               'mutateResponse/rval/value/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201402::CpmBid',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]' => 'Google::Ads::AdWords::v201402::BiddingError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'mutate/operations/operand/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'queryResponse/rval/entries/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'getResponse/rval/entries/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration' => 'Google::Ads::AdWords::v201402::BiddingStrategyConfiguration',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'mutateResponse/rval/partialFailureErrors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DateError]/reason' => 'Google::Ads::AdWords::v201402::DateError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'mutate/operations/operand/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201402::DatabaseError',
               'mutateResponse/rval/value/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201402::AdGroupCriterionError',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/reason' => 'Google::Ads::AdWords::v201402::RequestError::Reason',
               'getResponse/rval/entries/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'query' => 'Google::Ads::AdWords::v201402::AdGroupCriterionService::query',
               'getResponse/rval/entries[BiddableAdGroupCriterion]' => 'Google::Ads::AdWords::v201402::BiddableAdGroupCriterion',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201402::ManualCpcBiddingScheme',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201402::PolicyViolationKey',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'getResponse/rval/entries/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201402::ManualCpmBiddingScheme',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201402::AdGroupCriterionExperimentBidMultiplier',
               'mutate/operations/operand[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201402::RangeError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201402::BiddingStrategySource',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201402::AdGroupCriterionLimitExceeded',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]' => 'Google::Ads::AdWords::v201402::CpmBid',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201402::NotEmptyError',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]' => 'Google::Ads::AdWords::v201402::CpcBid',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CriterionError]' => 'Google::Ads::AdWords::v201402::CriterionError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/partialFailureErrors[RangeError]' => 'Google::Ads::AdWords::v201402::RangeError',
               'mutate/operations/operand/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201402::PercentCpaBiddingScheme',
               'mutateResponse/rval/partialFailureErrors[IdError]/reason' => 'Google::Ads::AdWords::v201402::IdError::Reason',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201402::CpaBid',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]' => 'Google::Ads::AdWords::v201402::BiddingErrors',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'mutate/operations/operand/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201402::ExperimentDeltaStatus',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201402::SortOrder',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201402::DateRange',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/targetRoas' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'mutateResponse/rval/value/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'mutateResponse/rval/value/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201402::UserStatus',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201402::SizeLimitError::Reason',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201402::PolicyViolationError::Part',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201402::StringLengthError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201402::ApprovalStatus',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201402::AuthenticationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201402::SystemServingStatus',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201402::QueryError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201402::EntityNotFound::Reason',
               'mutateResponse/rval/value/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201402::PolicyViolationError::Part',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/bid' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201402::Bid',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/reason' => 'Google::Ads::AdWords::v201402::BiddingError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme::PricingMode',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201402::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201402::ForwardCompatibilityError',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201402::NullError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'mutate/operations/operand/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201402::QualityInfo',
               'mutateResponse/rval/partialFailureErrors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/topOfPageCpc/amount' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ExperimentError]/reason' => 'Google::Ads::AdWords::v201402::ExperimentError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201402::ApprovalStatus',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'getResponse/rval/entries/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]' => 'Google::Ads::AdWords::v201402::AuthenticationError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201402::NotEmptyError::Reason',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'getResponse/rval/entries/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'mutateResponse/rval/partialFailureErrors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201402::SystemServingStatus',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[DateError]' => 'Google::Ads::AdWords::v201402::DateError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetRoasBiddingScheme',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]' => 'Google::Ads::AdWords::v201402::ManualCPCAdGroupCriterionExperimentBidMultiplier',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetSpendBiddingScheme',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'getResponse/rval/entries/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201402::PolicyViolationError',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201402::AdGroupCriterionExperimentBidMultiplier',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo' => 'Google::Ads::AdWords::v201402::QualityInfo',
               'mutateResponse/rval/partialFailureErrors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201402::EntityCountLimitExceeded::Reason',
               'mutateResponse/rval/value/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201402::EntityCountLimitExceeded',
               'getResponse/rval/entries/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201402::BiddingStrategyType',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201402::DistinctError',
               'mutateResponse/rval/partialFailureErrors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201402::OperationAccessDenied::Reason',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201402::IdError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201402::BiddableAdGroupCriterionExperimentData',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201402::OperationAccessDenied::Reason',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]' => 'Google::Ads::AdWords::v201402::DatabaseError',
               'queryResponse/rval/entries/criterion[ProductPartition]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'getResponse/rval/entries/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201402::BiddingStrategySource',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]' => 'Google::Ads::AdWords::v201402::DistinctError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'mutateResponse/rval/value/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]' => 'Google::Ads::AdWords::v201402::ReadOnlyError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Gender]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]' => 'Google::Ads::AdWords::v201402::AdxError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageQualityAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201402::NotEmptyError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201402::EnhancedCpcBiddingScheme',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201402::ForwardCompatibilityError',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201402::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201402::Paging',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201402::NewEntityCreationError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]' => 'Google::Ads::AdWords::v201402::ProductOfferId',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]' => 'Google::Ads::AdWords::v201402::EntityNotFound',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'getResponse/rval/entries/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'getResponse/rval/entries/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201402::UserStatus',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/approvalStatus' => 'Google::Ads::AdWords::v201402::ApprovalStatus',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201402::BiddingStrategySource',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201402::OperationAccessDenied',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]' => 'Google::Ads::AdWords::v201402::QueryError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201402::RateExceededError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201402::StringLengthError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201402::StatsQueryError::Reason',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Product]/conditions/operand' => 'Google::Ads::AdWords::v201402::ProductConditionOperand',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]' => 'Google::Ads::AdWords::v201402::ProductBiddingCategory',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201402::ExperimentDataStatus',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ExperimentError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201402::CpaBid',
               'getResponse/rval/entries/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201402::InternalApiError::Reason',
               'queryResponse/rval/entries/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201402::WebpageConditionOperand',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201402::QuotaCheckError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201402::DatabaseError::Reason',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityAccessDenied]/reason' => 'Google::Ads::AdWords::v201402::EntityAccessDenied::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetCpaBiddingScheme',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201402::ClientTermsError::Reason',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201402::MultiplierSource',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse' => 'Google::Ads::AdWords::v201402::AdGroupCriterionService::getResponse',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201402::NegativeAdGroupCriterion',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201402::CriterionError::Reason',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201402::CpaBid',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201402::ExperimentDeltaStatus',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/targetRoas' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201402::AuthorizationError::Reason',
               'queryResponse/rval/entries/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]' => 'Google::Ads::AdWords::v201402::RequiredError',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201402::InternalApiError::Reason',
               'queryResponse/rval/entries/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData' => 'Google::Ads::AdWords::v201402::BiddableAdGroupCriterionExperimentData',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201402::EnhancedCpcBiddingScheme',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetRoasBiddingScheme',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PagingError]/reason' => 'Google::Ads::AdWords::v201402::PagingError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'getResponse/rval/entries/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201402::EnhancedCpcBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'mutateResponse/rval/partialFailureErrors[AdxError]/reason' => 'Google::Ads::AdWords::v201402::AdxError::Reason',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201402::PercentCpaBiddingScheme',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201402::ExperimentDeltaStatus',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyType' => 'Google::Ads::AdWords::v201402::BiddingStrategyType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201402::SizeLimitError',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'mutateResponse/rval/partialFailureErrors[CriterionError]/reason' => 'Google::Ads::AdWords::v201402::CriterionError::Reason',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileApplication]' => 'Google::Ads::AdWords::v201402::MobileApplication',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201402::AdGroupCriterionExperimentBidMultiplier',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse' => 'Google::Ads::AdWords::v201402::AdGroupCriterionService::queryResponse',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'queryResponse/rval/entries/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201402::NewEntityCreationError::Reason',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201402::ForwardCompatibilityError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'queryResponse/rval/entries/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Keyword]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'mutateResponse/rval/partialFailureErrors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetSpendBiddingScheme',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201402::RequiredError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'getResponse/rval/entries/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingErrors]' => 'Google::Ads::AdWords::v201402::BiddingErrors',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Gender]/genderType' => 'Google::Ads::AdWords::v201402::Gender::GenderType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]/percentCpaBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityAccessDenied]' => 'Google::Ads::AdWords::v201402::EntityAccessDenied',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201402::BiddingScheme',
               'queryResponse/rval/entries/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/cpcBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]' => 'Google::Ads::AdWords::v201402::AgeRange',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Vertical]' => 'Google::Ads::AdWords::v201402::Vertical',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]' => 'Google::Ads::AdWords::v201402::QueryError',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme' => 'Google::Ads::AdWords::v201402::BiddingScheme',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/value/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'mutate/operations/operand/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Placement]' => 'Google::Ads::AdWords::v201402::Placement',
               'mutateResponse/rval/partialFailureErrors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201402::OperationAccessDenied',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201402::EntityCountLimitExceeded::Reason',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/parentCriterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'mutate/operations/operand[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition',
               'getResponse/rval/entries/criterion[AgeRange]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier' => 'Google::Ads::AdWords::v201402::AdGroupCriterionExperimentBidMultiplier',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]' => 'Google::Ads::AdWords::v201402::NegativeAdGroupCriterion',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutate/operations/operand/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/multiplierSource' => 'Google::Ads::AdWords::v201402::MultiplierSource',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'mutate/operations/operand/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201402::ManualCpcBiddingScheme',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201402::AdGroupCriterionError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ExperimentError]' => 'Google::Ads::AdWords::v201402::ExperimentError',
               'mutate/operations/operand[BiddableAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Product]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[ProductPartition]/caseValue[ProductOfferId]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion' => 'Google::Ads::AdWords::v201402::Criterion',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue' => 'Google::Ads::AdWords::v201402::ProductDimension',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201402::PageOnePromotedBiddingScheme::StrategyGoal',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetCpaBiddingScheme',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201402::String_StringMapEntry',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201402::BidMultiplier',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/AdGroupCriterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo/isKeywordAdRelevanceAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201402::Bids',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]' => 'Google::Ads::AdWords::v201402::ProductPartition',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/systemServingStatus' => 'Google::Ads::AdWords::v201402::SystemServingStatus',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201402::BudgetOptimizerBiddingScheme',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Keyword]/matchType' => 'Google::Ads::AdWords::v201402::KeywordMatchType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201402::Bid',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/criterion[Webpage]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[AgeRange]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/firstPageCpc' => 'Google::Ads::AdWords::v201402::Bid',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201402::PolicyViolationError',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids' => 'Google::Ads::AdWords::v201402::Bids',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Gender]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'mutateResponse/rval/partialFailureErrors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201402::AdGroupCriterionError',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]' => 'Google::Ads::AdWords::v201402::TargetRoasBiddingScheme',
               'mutate/operations/operand[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201402::ConversionOptimizerBiddingScheme::PricingMode',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Product]/conditions' => 'Google::Ads::AdWords::v201402::ProductCondition',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductTypeFull]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Product]' => 'Google::Ads::AdWords::v201402::Product',
               'mutateResponse/rval/value/criterion[AgeRange]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201402::QuotaCheckError::Reason',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Webpage]/parameter' => 'Google::Ads::AdWords::v201402::WebpageParameter',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCustomAttribute]' => 'Google::Ads::AdWords::v201402::ProductCustomAttribute',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201402::WebpageCondition',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201402::PercentCpaBiddingScheme',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201402::EntityCountLimitExceeded::Reason',
               'queryResponse/rval/entries/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201402::CriterionUserList::MembershipStatus',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201402::PercentCpaBid',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/criterion[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductBrand]' => 'Google::Ads::AdWords::v201402::ProductBrand',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/cpmBidSource' => 'Google::Ads::AdWords::v201402::BidSource',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/topOfPageCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/criterion[MobileApplication]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201402::EnhancedCpcBiddingScheme',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201402::IdError::Reason',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpaBid]' => 'Google::Ads::AdWords::v201402::CpaBid',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]' => 'Google::Ads::AdWords::v201402::CriterionUserInterest',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductOfferId]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/firstPageCpc/amount' => 'Google::Ads::AdWords::v201402::Money',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'mutate/operations/operand[NegativeAdGroupCriterion]/criterion[Gender]' => 'Google::Ads::AdWords::v201402::Gender',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Webpage]' => 'Google::Ads::AdWords::v201402::Webpage',
               'mutateResponse/rval/value/criterion[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[CriterionUserList]' => 'Google::Ads::AdWords::v201402::CriterionUserList',
               'mutateResponse/rval/value/criterion[AgeRange]/ageRangeType' => 'Google::Ads::AdWords::v201402::AgeRange::AgeRangeType',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductTypeFull]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201402::PageOnePromotedBiddingScheme::StrategyGoal',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[CriterionUserList]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'queryResponse/rval/entries/criterion[Gender]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductCustomAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/partitionType' => 'Google::Ads::AdWords::v201402::ProductPartitionType',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductTypeFull]' => 'Google::Ads::AdWords::v201402::ProductTypeFull',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201402::RateExceededError::Reason',
               'mutateResponse/rval/partialFailureErrors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]' => 'Google::Ads::AdWords::v201402::ProductLegacyCondition',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/type' => 'Google::Ads::AdWords::v201402::ProductDimensionType',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutate/operations/operand/criterion[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductCanonicalCondition]/condition' => 'Google::Ads::AdWords::v201402::ProductCanonicalCondition::Condition',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingStrategySource' => 'Google::Ads::AdWords::v201402::BiddingStrategySource',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/userStatus' => 'Google::Ads::AdWords::v201402::UserStatus',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsGrouping]' => 'Google::Ads::AdWords::v201402::ProductAdwordsGrouping',
               'mutateResponse/rval/value/criterion[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductBiddingCategory]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/criterion[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductLegacyCondition]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/Bids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileAppCategory]' => 'Google::Ads::AdWords::v201402::MobileAppCategory',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201402::RequestError::Reason',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Placement]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]' => 'Google::Ads::AdWords::v201402::InternalApiError',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[PercentCpaBid]' => 'Google::Ads::AdWords::v201402::PercentCpaBid',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/contentBid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpmBid]/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Vertical]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo/isLandingPageLatencyAcceptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/criterion[ProductPartition]/caseValue[ProductBrand]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/criterion[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries[NegativeAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]/ProductDimension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/criterion[ProductPartition]/caseValue[ProductAdwordsLabels]' => 'Google::Ads::AdWords::v201402::ProductAdwordsLabels',
               'query/query' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling' => 'Google::Ads::AdWords::v201402::Money',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201402::Criterion::Type',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/biddingStrategyConfiguration/bids[CpcBid]/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[BiddableAdGroupCriterion]/experimentData/experimentBidMultiplier[ManualCPCAdGroupCriterionExperimentBidMultiplier]/AdGroupCriterionExperimentBidMultiplier.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201402::AdGroupCriterion',
               'mutateResponse/rval/value[BiddableAdGroupCriterion]/qualityInfo/qualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterionUse' => 'Google::Ads::AdWords::v201402::CriterionUse',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[ProductPartition]/caseValue[ProductType]' => 'Google::Ads::AdWords::v201402::ProductType',
               'queryResponse/rval/entries[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201402::Money',
               'mutateResponse/rval/value/criterion[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ExperimentError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value[NegativeAdGroupCriterion]/criterion[Keyword]' => 'Google::Ads::AdWords::v201402::Keyword',
               'getResponse/rval/entries[NegativeAdGroupCriterion]/criterion[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[BiddableAdGroupCriterion]/criterion[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[BiddableAdGroupCriterion]/biddingStrategyConfiguration/biddingScheme[TargetRoasBiddingScheme]/bidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201402::TypeMaps::AdGroupCriterionService - typemap for AdGroupCriterionService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

