
package Google::Ads::AdWords::v201309::TypeMaps::TargetingIdeaService;
use strict;
use warnings;

our $typemap_1 = {
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min' => 'Google::Ads::AdWords::v201309::ComparableValue',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]' => 'Google::Ads::AdWords::v201309::CriterionBidLandscape',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes/FlashDisplayType' => 'Google::Ads::AdWords::v201309::FlashDisplayType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/adSizeSpecs' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::AdSizeSpec',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[LongValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/preRollPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[Money]' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/bid' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]' => 'Google::Ads::AdWords::v201309::LongRangeAttribute',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/currencyCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[SearchVolumeSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[IdeaTextFilterSearchParameter]/excluded' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[IdeaTypeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/DataEntry.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/InStreamAdSpec/durations' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/TextAdSpec' => 'Google::Ads::AdWords::v201309::TextAdSpec',
               'get/selector/searchParameters[NetworkSearchParameter]/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval' => 'Google::Ads::AdWords::v201309::TargetingIdeaPage',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/InStreamAdSpec' => 'Google::Ads::AdWords::v201309::InStreamAdSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/bid' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[InStreamAdInfoAttribute]' => 'Google::Ads::AdWords::v201309::InStreamAdInfoAttribute',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/reason' => 'Google::Ads::AdWords::v201309::CurrencyCodeError::Reason',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[RelatedToQuerySearchParameter]' => 'Google::Ads::AdWords::v201309::RelatedToQuerySearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/DataEntry.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LanguageSearchParameter]' => 'Google::Ads::AdWords::v201309::LanguageSearchParameter',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/limitType' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded::CriteriaLimitType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes/ImageDisplayType' => 'Google::Ads::AdWords::v201309::ImageDisplayType',
               'getBulkKeywordIdeas/selector/searchParameters[NetworkSearchParameter]/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/data/value' => 'Google::Ads::AdWords::v201309::Attribute',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[DoubleAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[SearchVolumeSearchParameter]/operation/maximum' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/cost' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeas/selector/searchParameters[IdeaTextFilterSearchParameter]/included' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getBulkKeywordIdeas/selector/searchParameters[NetworkSearchParameter]' => 'Google::Ads::AdWords::v201309::NetworkSearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[IntegerSetAttribute]' => 'Google::Ads::AdWords::v201309::IntegerSetAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[StringAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MoneyAttribute]' => 'Google::Ads::AdWords::v201309::MoneyAttribute',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[CompetitionSearchParameter]' => 'Google::Ads::AdWords::v201309::CompetitionSearchParameter',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[AdFormatSpecListAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/adSizeSpecs/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/adSizeSpecs/activationOptionFilter' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::ActivationOption',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[KeywordAttribute]/value/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/adSizeSpecs' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::AdSizeSpec',
               'get/selector/searchParameters[NetworkSearchParameter]' => 'Google::Ads::AdWords::v201309::NetworkSearchParameter',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[ExcludedKeywordSearchParameter]' => 'Google::Ads::AdWords::v201309::ExcludedKeywordSearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[IntegerAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/marginalCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters' => 'Google::Ads::AdWords::v201309::SearchParameter',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[DoubleValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/InStreamAdSpec' => 'Google::Ads::AdWords::v201309::InStreamAdSpec',
               'getResponse/rval/entries/data/value[IntegerSetAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[WebpageDescriptorAttribute]/value/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[PlacementAttribute]' => 'Google::Ads::AdWords::v201309::PlacementAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[InStreamAdInfoAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[Money]' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeas/selector/searchParameters[PlacementTypeSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[Money]/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]' => 'Google::Ads::AdWords::v201309::CriterionAttribute',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetingIdeaError]/reason' => 'Google::Ads::AdWords::v201309::TargetingIdeaError::Reason',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]' => 'Google::Ads::AdWords::v201309::BiddingError',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/ideaType' => 'Google::Ads::AdWords::v201309::IdeaType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[IntegerAttribute]' => 'Google::Ads::AdWords::v201309::IntegerAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/marginalCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[KeywordAttribute]' => 'Google::Ads::AdWords::v201309::KeywordAttribute',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval' => 'Google::Ads::AdWords::v201309::TargetingIdeaPage',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'getBulkKeywordIdeas/selector/searchParameters[SearchVolumeSearchParameter]/operation/minimum' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/marginalCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[ExcludedKeywordSearchParameter]' => 'Google::Ads::AdWords::v201309::ExcludedKeywordSearchParameter',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords' => 'Google::Ads::AdWords::v201309::Keyword',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdFormatSpecListAttribute]/value' => 'Google::Ads::AdWords::v201309::AdFormatSpec',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/postRollPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[OpportunityIdeaTypeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]' => 'Google::Ads::AdWords::v201309::MonthlySearchVolumeAttribute',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value' => 'Google::Ads::AdWords::v201309::Criterion',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[Money]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[IdeaTypeAttribute]' => 'Google::Ads::AdWords::v201309::IdeaTypeAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[InStreamAdInfoAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[CategoryProductsAndServicesSearchParameter]' => 'Google::Ads::AdWords::v201309::CategoryProductsAndServicesSearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[DoubleValue]' => 'Google::Ads::AdWords::v201309::DoubleValue',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'getResponse/rval/entries/data/value[IntegerSetAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[OpportunityIdeaTypeAttribute]' => 'Google::Ads::AdWords::v201309::OpportunityIdeaTypeAttribute',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/paging' => 'Google::Ads::AdWords::v201309::Paging',
               'get/selector/searchParameters[RelatedToUrlSearchParameter]/urls' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[StringAttribute]' => 'Google::Ads::AdWords::v201309::StringAttribute',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementAttribute]/value/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]' => 'Google::Ads::AdWords::v201309::AdGroupBidLandscape',
               'getResponse/rval/entries/data/value[KeywordAttribute]/value' => 'Google::Ads::AdWords::v201309::Keyword',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[LongValue]/number' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/marginalCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[InStreamAdInfoAttribute]' => 'Google::Ads::AdWords::v201309::InStreamAdInfoAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[WebpageDescriptorAttribute]' => 'Google::Ads::AdWords::v201309::WebpageDescriptorAttribute',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[IdeaTextFilterSearchParameter]' => 'Google::Ads::AdWords::v201309::IdeaTextFilterSearchParameter',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/path' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]' => 'Google::Ads::AdWords::v201309::Webpage',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/marginalCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/postRollPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongAttribute]' => 'Google::Ads::AdWords::v201309::LongAttribute',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[IdeaTypeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[CategoryProductsAndServicesSearchParameter]/categoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[Money]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/midRollPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[LongValue]/number' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[PlacementAttribute]/value/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/activationOptions' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::ActivationOption',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]' => 'Google::Ads::AdWords::v201309::LocationSearchParameter',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[NumberValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BooleanAttribute]' => 'Google::Ads::AdWords::v201309::BooleanAttribute',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementAttribute]/value/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[KeywordAttribute]' => 'Google::Ads::AdWords::v201309::KeywordAttribute',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[NetworkSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LanguageSearchParameter]' => 'Google::Ads::AdWords::v201309::LanguageSearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]' => 'Google::Ads::AdWords::v201309::MonthlySearchVolumeAttribute',
               'getResponse/rval/entries/data/value[LongAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[PlacementAttribute]/value/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]' => 'Google::Ads::AdWords::v201309::CollectionSizeError',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[PlacementTypeSearchParameter]/placementTypes' => 'Google::Ads::AdWords::v201309::SiteConstants::PlacementType',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/marginalCpc' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeas/selector/searchParameters[LanguageSearchParameter]/languages/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes/ImageDisplayType' => 'Google::Ads::AdWords::v201309::ImageDisplayType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]' => 'Google::Ads::AdWords::v201309::CriterionBidLandscape',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupCriterionLimitExceeded',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[DoubleValue]/number' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BooleanAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[Money]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[MoneyAttribute]/value/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/activationOptions' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::ActivationOption',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[TargetingIdeaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LanguageSearchParameter]/languages/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[Money]/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas' => 'Google::Ads::AdWords::v201309::TargetingIdeaService::getBulkKeywordIdeas',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes/ImageDisplayType' => 'Google::Ads::AdWords::v201309::ImageDisplayType',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[KeywordAttribute]/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/marginalCpc' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[RelatedToQuerySearchParameter]' => 'Google::Ads::AdWords::v201309::RelatedToQuerySearchParameter',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[IntegerSetAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[SearchVolumeSearchParameter]/operation' => 'Google::Ads::AdWords::v201309::LongComparisonOperation',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[DoubleAttribute]' => 'Google::Ads::AdWords::v201309::DoubleAttribute',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[Money]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[NetworkSearchParameter]/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[LongValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/adSizeSpecs' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::AdSizeSpec',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LanguageSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/DataEntry.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get' => 'Google::Ads::AdWords::v201309::TargetingIdeaService::get',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/TextAdSpec' => 'Google::Ads::AdWords::v201309::TextAdSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/adSizeSpecs/activationOptionFilter' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::ActivationOption',
               'get/selector/searchParameters[NetworkSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[RelatedToQuerySearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]' => 'Google::Ads::AdWords::v201309::AdSpecListAttribute',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'get/selector/searchParameters[CompetitionSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[KeywordAttribute]/value' => 'Google::Ads::AdWords::v201309::Keyword',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/marginalCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[DoubleValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/promotedImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/activationOptions' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::ActivationOption',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementAttribute]' => 'Google::Ads::AdWords::v201309::PlacementAttribute',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[Money]' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeas/selector/searchParameters[LanguageSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/marginalCpc' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/marginalCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[NetworkSearchParameter]/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]' => 'Google::Ads::AdWords::v201309::BudgetError',
               'getResponse/rval/entries/data/value[BooleanAttribute]' => 'Google::Ads::AdWords::v201309::BooleanAttribute',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[NumberValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/value/count' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/InStreamAdSpec/inStreamTypes' => 'Google::Ads::AdWords::v201309::InStreamAdSpec::InStreamType',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[NumberValue]' => 'Google::Ads::AdWords::v201309::NumberValue',
               'getBulkKeywordIdeas/selector/searchParameters[NetworkSearchParameter]/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[KeywordAttribute]/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/reason' => 'Google::Ads::AdWords::v201309::MatchesRegexError::Reason',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes/HtmlDisplayType' => 'Google::Ads::AdWords::v201309::HtmlDisplayType',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'getBulkKeywordIdeas/selector/searchParameters[CategoryProductsAndServicesSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/adSizeSpecs/activationOptionFilter' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::ActivationOption',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes/HtmlDisplayType' => 'Google::Ads::AdWords::v201309::HtmlDisplayType',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]' => 'Google::Ads::AdWords::v201309::BidLandscapeAttribute',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value' => 'Google::Ads::AdWords::v201309::BidLandscape',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[SearchVolumeSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/adSizeSpecs/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[WebpageDescriptorAttribute]/value/title' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[DoubleAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[IncludeAdultContentSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[KeywordAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/bid' => 'Google::Ads::AdWords::v201309::Money',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/DataEntry.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes/FlashDisplayType' => 'Google::Ads::AdWords::v201309::FlashDisplayType',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]' => 'Google::Ads::AdWords::v201309::AdGroupBidLandscape',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/adSizeSpecs/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongAttribute]' => 'Google::Ads::AdWords::v201309::LongAttribute',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/DataEntry.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[RelatedToUrlSearchParameter]/urls' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max' => 'Google::Ads::AdWords::v201309::ComparableValue',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/userListId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[WebpageDescriptorAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[StringAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LanguageSearchParameter]/languages/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[IntegerAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/value/count' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/TextAdSpec' => 'Google::Ads::AdWords::v201309::TextAdSpec',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Language]' => 'Google::Ads::AdWords::v201309::Language',
               'getBulkKeywordIdeasResponse/rval/entries' => 'Google::Ads::AdWords::v201309::TargetingIdea',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/marginalCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/key' => 'Google::Ads::AdWords::v201309::AttributeType',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[OpportunityIdeaTypeAttribute]/value' => 'Google::Ads::AdWords::v201309::OpportunityIdeaType',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LanguageSearchParameter]/languages/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/ideaType' => 'Google::Ads::AdWords::v201309::IdeaType',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]' => 'Google::Ads::AdWords::v201309::Keyword',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MoneyAttribute]/value/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/marginalCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BooleanAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/localeCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[LongValue]' => 'Google::Ads::AdWords::v201309::NumberValue',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'get/selector/searchParameters[IdeaTextFilterSearchParameter]/included' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[DoubleValue]/number' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/data/value[KeywordAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[KeywordAttribute]/value/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[RelatedToUrlSearchParameter]/includeSubUrls' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'getResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/minAdDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[NetworkSearchParameter]/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/value/month' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/marginalCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec' => 'Google::Ads::AdWords::v201309::DisplayAdSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/marginalCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]' => 'Google::Ads::AdWords::v201309::CriterionUserList',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201309::BiddingError::Reason',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[IdeaTextFilterSearchParameter]/excluded' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupCriterionError::Reason',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]' => 'Google::Ads::AdWords::v201309::AdSpecListSearchParameter',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/conditions' => 'Google::Ads::AdWords::v201309::ProductCondition',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MoneyAttribute]/value' => 'Google::Ads::AdWords::v201309::Money',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints' => 'Google::Ads::AdWords::v201309::BidLandscape::LandscapePoint',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[IdeaTextFilterSearchParameter]' => 'Google::Ads::AdWords::v201309::IdeaTextFilterSearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[RelatedToUrlSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/adSizeSpecs' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::AdSizeSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[WebpageDescriptorAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/activationOptions' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::ActivationOption',
               'getResponse/rval/entries/data/value[MoneyAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[PlacementTypeAttribute]' => 'Google::Ads::AdWords::v201309::PlacementTypeAttribute',
               'getResponse/rval/entries/data/value[PlacementAttribute]/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[AdSpecListSearchParameter]' => 'Google::Ads::AdWords::v201309::AdSpecListSearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]' => 'Google::Ads::AdWords::v201309::LongRangeAttribute',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/minAdDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[NetworkSearchParameter]/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[PlacementTypeSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[Money]/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[OpportunityIdeaTypeAttribute]' => 'Google::Ads::AdWords::v201309::OpportunityIdeaTypeAttribute',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters' => 'Google::Ads::AdWords::v201309::SearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/maxAdDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]' => 'Google::Ads::AdWords::v201309::MatchesRegexError',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[DoubleValue]/number' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[NetworkSearchParameter]/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/InStreamAdSpec/durations' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[MoneyAttribute]/value' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[WebpageDescriptorAttribute]/value' => 'Google::Ads::AdWords::v201309::WebpageDescriptor',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[DoubleValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[NumberValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/adSizeSpecs/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value' => 'Google::Ads::AdWords::v201309::BidLandscape',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[RelatedToQuerySearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[IntegerAttribute]' => 'Google::Ads::AdWords::v201309::IntegerAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[KeywordAttribute]/value/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[KeywordAttribute]/value/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value' => 'Google::Ads::AdWords::v201309::Range',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[OpportunityIdeaTypeAttribute]/value' => 'Google::Ads::AdWords::v201309::OpportunityIdeaType',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]' => 'Google::Ads::AdWords::v201309::RegionCodeError',
               'get/selector/searchParameters[LocationSearchParameter]' => 'Google::Ads::AdWords::v201309::LocationSearchParameter',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/cost' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[PlacementTypeSearchParameter]' => 'Google::Ads::AdWords::v201309::PlacementTypeSearchParameter',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/promotedImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[MoneyAttribute]/value/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]' => 'Google::Ads::AdWords::v201309::Placement',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201309::TargetingIdea',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LanguageSearchParameter]/languages/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[PlacementTypeSearchParameter]/placementTypes' => 'Google::Ads::AdWords::v201309::SiteConstants::PlacementType',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/adSizeSpecs/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[KeywordAttribute]/value/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/midRollPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getBulkKeywordIdeas/selector/searchParameters[IdeaTextFilterSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapeCurrent' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]' => 'Google::Ads::AdWords::v201309::TargetError',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/InStreamAdSpec/durations' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[NumberValue]' => 'Google::Ads::AdWords::v201309::NumberValue',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/reason' => 'Google::Ads::AdWords::v201309::RegionCodeError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/userListName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs' => 'Google::Ads::AdWords::v201309::AdSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/displayName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints' => 'Google::Ads::AdWords::v201309::BidLandscape::LandscapePoint',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]' => 'Google::Ads::AdWords::v201309::AdSpecListAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BooleanAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[SearchVolumeSearchParameter]' => 'Google::Ads::AdWords::v201309::SearchVolumeSearchParameter',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value' => 'Google::Ads::AdWords::v201309::AdSpec',
               'get/selector/searchParameters[RelatedToUrlSearchParameter]' => 'Google::Ads::AdWords::v201309::RelatedToUrlSearchParameter',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/InStreamAdSpec/inStreamTypes' => 'Google::Ads::AdWords::v201309::InStreamAdSpec::InStreamType',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/marginalCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/type' => 'Google::Ads::AdWords::v201309::AdGroupBidLandscape::Type',
               'getResponse/rval/entries/data/value[KeywordAttribute]/value/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'getResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/preRollPercent' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[IdeaTypeAttribute]/value' => 'Google::Ads::AdWords::v201309::IdeaType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/value' => 'Google::Ads::AdWords::v201309::MonthlySearchVolume',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value' => 'Google::Ads::AdWords::v201309::InStreamAdInfo',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[SearchVolumeSearchParameter]/operation/maximum' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[AdFormatSpecListAttribute]/value/format' => 'Google::Ads::AdWords::v201309::SiteConstants::AdFormat',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/paging' => 'Google::Ads::AdWords::v201309::Paging',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse' => 'Google::Ads::AdWords::v201309::TargetingIdeaService::getResponse',
               'getResponse/rval/entries/data/value[KeywordAttribute]/value/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[RelatedToQuerySearchParameter]/queries' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[IncludeAdultContentSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/medianAdDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapeCurrent' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementAttribute]/value/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[DoubleValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/reason' => 'Google::Ads::AdWords::v201309::CriterionError::Reason',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/criteriaCoverage' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/requestedAttributeTypes' => 'Google::Ads::AdWords::v201309::AttributeType',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints' => 'Google::Ads::AdWords::v201309::BidLandscape::LandscapePoint',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[SearchVolumeSearchParameter]/operation/minimum' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/conditions/operand' => 'Google::Ads::AdWords::v201309::WebpageConditionOperand',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/reason' => 'Google::Ads::AdWords::v201309::BudgetError::Reason',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[CategoryProductsAndServicesSearchParameter]' => 'Google::Ads::AdWords::v201309::CategoryProductsAndServicesSearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementTypeAttribute]/value' => 'Google::Ads::AdWords::v201309::SiteConstants::PlacementType',
               'get/selector/requestType' => 'Google::Ads::AdWords::v201309::RequestType',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/InStreamAdSpec/durations' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'get/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords' => 'Google::Ads::AdWords::v201309::Keyword',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]' => 'Google::Ads::AdWords::v201309::MobileApplication',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/marginalCpc' => 'Google::Ads::AdWords::v201309::Money',
               'get/selector/searchParameters[CategoryProductsAndServicesSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/reason' => 'Google::Ads::AdWords::v201309::TrafficEstimatorError::Reason',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/userInterestName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector' => 'Google::Ads::AdWords::v201309::TargetingIdeaSelector',
               'get/selector/searchParameters[IdeaTextFilterSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'getResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/maxAdDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/adSizeSpecs/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[AdSpecListSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[NumberValue]' => 'Google::Ads::AdWords::v201309::NumberValue',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/value' => 'Google::Ads::AdWords::v201309::MonthlySearchVolume',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]' => 'Google::Ads::AdWords::v201309::CriterionUserInterest',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[CompetitionSearchParameter]/levels' => 'Google::Ads::AdWords::v201309::CompetitionSearchParameter::Level',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes' => 'Google::Ads::AdWords::v201309::DisplayType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value' => 'Google::Ads::AdWords::v201309::AdSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MoneyAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes/HtmlDisplayType' => 'Google::Ads::AdWords::v201309::HtmlDisplayType',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[MoneyAttribute]' => 'Google::Ads::AdWords::v201309::MoneyAttribute',
               'getBulkKeywordIdeas/selector/searchParameters[LanguageSearchParameter]/languages' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes/FlashDisplayType' => 'Google::Ads::AdWords::v201309::FlashDisplayType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getResponse/rval/entries/data/value[PlacementTypeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec' => 'Google::Ads::AdWords::v201309::DisplayAdSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[LongValue]' => 'Google::Ads::AdWords::v201309::NumberValue',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints' => 'Google::Ads::AdWords::v201309::BidLandscape::LandscapePoint',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LanguageSearchParameter]/languages/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes/HtmlDisplayType/htmlOption' => 'Google::Ads::AdWords::v201309::HtmlDisplayType::HtmlOption',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/adSizeSpecs/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs' => 'Google::Ads::AdWords::v201309::AdSpec',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints' => 'Google::Ads::AdWords::v201309::BidLandscape::LandscapePoint',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/localeCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[LongValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]' => 'Google::Ads::AdWords::v201309::Platform',
               'getResponse/rval/entries/data/value[WebpageDescriptorAttribute]' => 'Google::Ads::AdWords::v201309::WebpageDescriptorAttribute',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/verticalParentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/verticalId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementTypeAttribute]' => 'Google::Ads::AdWords::v201309::PlacementTypeAttribute',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/promotedImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[AdFormatSpecListAttribute]/value' => 'Google::Ads::AdWords::v201309::AdFormatSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/DataEntry.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/currencyCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[DoubleValue]/number' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[SearchVolumeSearchParameter]/operation' => 'Google::Ads::AdWords::v201309::LongComparisonOperation',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value' => 'Google::Ads::AdWords::v201309::Range',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BooleanAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[TargetingIdeaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[SearchVolumeSearchParameter]' => 'Google::Ads::AdWords::v201309::SearchVolumeSearchParameter',
               'get/selector/searchParameters[NetworkSearchParameter]/networkSetting' => 'Google::Ads::AdWords::v201309::NetworkSetting',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/conditions' => 'Google::Ads::AdWords::v201309::WebpageCondition',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[LongValue]' => 'Google::Ads::AdWords::v201309::NumberValue',
               'getResponse/rval/entries/data/value[PlacementAttribute]/value/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/value/year' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/bid' => 'Google::Ads::AdWords::v201309::Money',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/criteriaSamples' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[CategoryProductsAndServicesSearchParameter]/categoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/bid' => 'Google::Ads::AdWords::v201309::Money',
               'get/selector/searchParameters[NetworkSearchParameter]/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/data/value[CriterionAttribute]' => 'Google::Ads::AdWords::v201309::CriterionAttribute',
               'getResponse/rval/entries/data/value[IdeaTypeAttribute]/value' => 'Google::Ads::AdWords::v201309::IdeaType',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/criterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]' => 'Google::Ads::AdWords::v201309::CurrencyCodeError',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter' => 'Google::Ads::AdWords::v201309::WebpageParameter',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector' => 'Google::Ads::AdWords::v201309::TargetingIdeaSelector',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes/FlashDisplayType' => 'Google::Ads::AdWords::v201309::FlashDisplayType',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[Money]' => 'Google::Ads::AdWords::v201309::Money',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[IntegerAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/cost' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes/HtmlDisplayType/htmlOption' => 'Google::Ads::AdWords::v201309::HtmlDisplayType::HtmlOption',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/value/month' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[DoubleAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/mobileAppCategoryId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[ExcludedKeywordSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserInterest]/userInterestId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes/HtmlDisplayType/htmlOption' => 'Google::Ads::AdWords::v201309::HtmlDisplayType::HtmlOption',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[WebpageDescriptorAttribute]/value/title' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/requestType' => 'Google::Ads::AdWords::v201309::RequestType',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[StringAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[PlacementTypeSearchParameter]' => 'Google::Ads::AdWords::v201309::PlacementTypeSearchParameter',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]' => 'Google::Ads::AdWords::v201309::TrafficEstimatorError',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[PlacementAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[IncludeAdultContentSearchParameter]' => 'Google::Ads::AdWords::v201309::IncludeAdultContentSearchParameter',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementAttribute]/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/TextAdSpec' => 'Google::Ads::AdWords::v201309::TextAdSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Placement]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[LongValue]/number' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/key' => 'Google::Ads::AdWords::v201309::AttributeType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]' => 'Google::Ads::AdWords::v201309::CriterionError',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdFormatSpecListAttribute]' => 'Google::Ads::AdWords::v201309::AdFormatSpecListAttribute',
               'Fault/detail/ApiExceptionFault/errors[TargetingIdeaError]' => 'Google::Ads::AdWords::v201309::TargetingIdeaError',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdFormatSpecListAttribute]/value/format' => 'Google::Ads::AdWords::v201309::SiteConstants::AdFormat',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[PlacementAttribute]/value' => 'Google::Ads::AdWords::v201309::Placement',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/userListMembershipStatus' => 'Google::Ads::AdWords::v201309::CriterionUserList::MembershipStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[IncludeAdultContentSearchParameter]' => 'Google::Ads::AdWords::v201309::IncludeAdultContentSearchParameter',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes/HtmlDisplayType' => 'Google::Ads::AdWords::v201309::HtmlDisplayType',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Vertical]' => 'Google::Ads::AdWords::v201309::Vertical',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/promotedImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[DoubleValue]' => 'Google::Ads::AdWords::v201309::DoubleValue',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/criterionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[ExcludedKeywordSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[CompetitionSearchParameter]/levels' => 'Google::Ads::AdWords::v201309::CompetitionSearchParameter::Level',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RegionCodeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LanguageSearchParameter]/languages' => 'Google::Ads::AdWords::v201309::Language',
               'getResponse/rval/entries/data/value[IntegerSetAttribute]' => 'Google::Ads::AdWords::v201309::IntegerSetAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/criterionName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes' => 'Google::Ads::AdWords::v201309::DisplayType',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[DoubleValue]' => 'Google::Ads::AdWords::v201309::DoubleValue',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[NumberValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[TrafficEstimatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LanguageSearchParameter]/languages/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/text' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse' => 'Google::Ads::AdWords::v201309::TargetingIdeaService::getBulkKeywordIdeasResponse',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[CurrencyCodeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes/ImageDisplayType' => 'Google::Ads::AdWords::v201309::ImageDisplayType',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[IdeaTypeAttribute]' => 'Google::Ads::AdWords::v201309::IdeaTypeAttribute',
               'getBulkKeywordIdeas/selector/searchParameters[CompetitionSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]' => 'Google::Ads::AdWords::v201309::BidLandscapeAttribute',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[StringAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/adSizeSpecs/activationOptionFilter' => 'Google::Ads::AdWords::v201309::DisplayAdSpec::ActivationOption',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[CompetitionSearchParameter]' => 'Google::Ads::AdWords::v201309::CompetitionSearchParameter',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value/medianAdDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[OpportunityIdeaTypeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[WebpageDescriptorAttribute]/value/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[LongValue]' => 'Google::Ads::AdWords::v201309::NumberValue',
               'Fault/detail/ApiExceptionFault/errors[TargetingIdeaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[AdFormatSpecListAttribute]' => 'Google::Ads::AdWords::v201309::AdFormatSpecListAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[IntegerAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201309::TargetError::Reason',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/requestedAttributeTypes' => 'Google::Ads::AdWords::v201309::AttributeType',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MoneyAttribute]/value/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max[Money]/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/cost' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[RelatedToUrlSearchParameter]/SearchParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/InStreamAdSpec/inStreamTypes' => 'Google::Ads::AdWords::v201309::InStreamAdSpec::InStreamType',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value' => 'Google::Ads::AdWords::v201309::Attribute',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints' => 'Google::Ads::AdWords::v201309::BidLandscape::LandscapePoint',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/promotedImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Webpage]/parameter/CriterionParameter.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec' => 'Google::Ads::AdWords::v201309::DisplayAdSpec',
               'getResponse/rval/entries/data/value[LongAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[RelatedToQuerySearchParameter]/queries' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[RelatedToUrlSearchParameter]/includeSubUrls' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Product]/conditions/operand' => 'Google::Ads::AdWords::v201309::ProductConditionOperand',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/InStreamAdSpec' => 'Google::Ads::AdWords::v201309::InStreamAdSpec',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[WebpageDescriptorAttribute]/value' => 'Google::Ads::AdWords::v201309::WebpageDescriptor',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[StringAttribute]' => 'Google::Ads::AdWords::v201309::StringAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[IntegerSetAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Keyword]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes' => 'Google::Ads::AdWords::v201309::DisplayType',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[NumberValue]' => 'Google::Ads::AdWords::v201309::NumberValue',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]' => 'Google::Ads::AdWords::v201309::CriterionPolicyError',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/bid/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/marginalCpc' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/adSizeSpecs/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/min[LongValue]/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileAppCategory]' => 'Google::Ads::AdWords::v201309::MobileAppCategory',
               'getBulkKeywordIdeas/selector/searchParameters[LanguageSearchParameter]/languages/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementTypeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/promotedImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[CriterionUserList]/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/InStreamAdSpec/inStreamTypes' => 'Google::Ads::AdWords::v201309::InStreamAdSpec::InStreamType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min[LongValue]/number' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/bid' => 'Google::Ads::AdWords::v201309::Money',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Product]' => 'Google::Ads::AdWords::v201309::Product',
               'getBulkKeywordIdeas/selector/searchParameters[RelatedToUrlSearchParameter]' => 'Google::Ads::AdWords::v201309::RelatedToUrlSearchParameter',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[TargetingIdeaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data' => 'Google::Ads::AdWords::v201309::Type_AttributeMapEntry',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/bid/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/value/max[DoubleValue]' => 'Google::Ads::AdWords::v201309::DoubleValue',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[InStreamAdInfoAttribute]/value' => 'Google::Ads::AdWords::v201309::InStreamAdInfo',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value/landscapePoints/cost' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[DoubleAttribute]' => 'Google::Ads::AdWords::v201309::DoubleAttribute',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value' => 'Google::Ads::AdWords::v201309::Criterion',
               'getBulkKeywordIdeas/selector/searchParameters[ExcludedKeywordSearchParameter]/keywords/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/DisplayAdSpec/displayTypes' => 'Google::Ads::AdWords::v201309::DisplayType',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/entries/data/value[KeywordAttribute]/value/matchType' => 'Google::Ads::AdWords::v201309::KeywordMatchType',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/data/value[DoubleAttribute]/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/data/value[PlacementTypeAttribute]/value' => 'Google::Ads::AdWords::v201309::SiteConstants::PlacementType',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/max' => 'Google::Ads::AdWords::v201309::ComparableValue',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data' => 'Google::Ads::AdWords::v201309::Type_AttributeMapEntry',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LanguageSearchParameter]/languages/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[MonthlySearchVolumeAttribute]/value/year' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[LongRangeAttribute]/value/min' => 'Google::Ads::AdWords::v201309::ComparableValue',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/type' => 'Google::Ads::AdWords::v201309::AdGroupBidLandscape::Type',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[CriterionBidLandscape]/landscapePoints/marginalCpc' => 'Google::Ads::AdWords::v201309::Money',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec' => 'Google::Ads::AdWords::v201309::DisplayAdSpec',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[BidLandscapeAttribute]/value[AdGroupBidLandscape]/landscapePoints/cost' => 'Google::Ads::AdWords::v201309::Money',
               'getBulkKeywordIdeas/selector/searchParameters[AdSpecListSearchParameter]/adSpecs/InStreamAdSpec' => 'Google::Ads::AdWords::v201309::InStreamAdSpec',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Location]/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/targetingStatus' => 'Google::Ads::AdWords::v201309::LocationTargetingStatus',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/displayType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[PlacementAttribute]/value' => 'Google::Ads::AdWords::v201309::Placement',
               'get/selector/searchParameters[LanguageSearchParameter]/languages/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[LongRangeAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdSpecListAttribute]/value/DisplayAdSpec/displayTypes/HtmlDisplayType/htmlOption' => 'Google::Ads::AdWords::v201309::HtmlDisplayType::HtmlOption',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations' => 'Google::Ads::AdWords::v201309::Location',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Platform]/platformName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CriterionPolicyError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getBulkKeywordIdeasResponse/rval/entries/data/value[AdFormatSpecListAttribute]/Attribute.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupCriterionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/locationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MatchesRegexError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[Language]/code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/data/value[CriterionAttribute]/value[MobileApplication]/Criterion.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getBulkKeywordIdeas/selector/searchParameters[LocationSearchParameter]/locations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/parentLocations/type' => 'Google::Ads::AdWords::v201309::Criterion::Type'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201309::TypeMaps::TargetingIdeaService - typemap for TargetingIdeaService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

